@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: application.cpp,v 1.44 2005/07/10 01:32:44 bherger Exp $
+** $Id: application.cpp,v 1.46 2005/11/16 03:01:55 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -19,6 +19,7 @@ using std::cout;
 using std::endl;
 
 #include <qglobal.h>
+#include <qdatetime.h>
 #include <qimage.h>
 #include <qbitmap.h>
 #include <qpixmap.h>
@@ -639,6 +640,10 @@ ApplicationWindow::ApplicationWindow()
   file->setWhatsThis( id, fileSaveText );
   id = file->insertItem( tr("Save picture..."), this, SLOT(savePicture()) );
 
+  file->insertSeparator();
+  id = file->insertItem( tr("Send to &external program..."), 
+			 this, SLOT(externalProgram()) );
+
   file->insertSeparator();
   id = file->insertItem( tr("Pa&ge setup"), this , SLOT(PageSetup()) );
   id = file->insertItem( printIcon, tr("&Print"),
@@ -831,6 +836,61 @@ QPopupMenu *ApplicationWindow::BuildRingMenu() {
 }
 */
 
+// externalProgram() sends to an external program
+void ApplicationWindow::externalProgram() {
+  // supported programs
+#define PROGRAM_KRYOMOL 1
+#define PROGRAM_GHEMICAL 2
+
+  int sendto = 0, qbox, passfail = 0;
+  QString exportFileName;
+  qbox = QMessageBox::question( this,
+				tr("Send to external program"),
+				tr("This function will open a 3-D version of one molecule\nin an external modelling program.\n\nSend to program:"),
+				tr("Ghemical"),
+				tr("KryoMol"),
+				tr("Cancel"),
+				2
+				);
+  if (qbox == 0) sendto = 1;
+  if (qbox == 1) sendto = 2;
+  if (qbox == 2) sendto = 0;
+
+  if ( sendto > 0 ) {
+    exportFileName = QDateTime::currentDateTime().toString("MMddhhmmsszzz");
+    exportFileName.append(".mol");
+    exportFileName.prepend("/tmp/");
+    std::cout << "export " << exportFileName << std::endl;
+    c->firstMolecule()->Make3DVersion(exportFileName);
+    if (QFile::exists(exportFileName) == false) {
+      QMessageBox::critical( this,
+			     tr("Send to external program failed"),
+			     tr("Could not save file for external program.")
+			     );
+      return;
+    }
+    if (sendto == 1) {
+      std::cout << "Ghemical: ";
+      exportFileName.prepend("ghemical ");
+      passfail = system(exportFileName.ascii());
+      std::cout << passfail << std::endl;
+    }
+    if (sendto == 2) {
+      std::cout << "KryoMol: ";
+      exportFileName.prepend("kryomol ");
+      passfail = system(exportFileName.ascii());
+      std::cout << passfail << std::endl;
+    }
+    if (passfail != 0) {
+      QMessageBox::critical( this,
+			     tr("Send to external program failed"),
+			     tr("Could not execute the external program.\nPlease verify that it is installed correctly.")
+			     );
+      return;
+    }
+  }
+}
+
 QPopupMenu *ApplicationWindow::BuildSymbolMenu() {
   QPopupMenu * symbolSub = new QPopupMenu(this);
   QPixmap p1;
@@ -1225,41 +1285,6 @@ void ApplicationWindow::saveAs()
 {
   OBExport();
   return;
-
-  /* DELETE ME
-  QFileDialog fd(QString::null, QString::null, 0, 0, TRUE);
-  fd.setCaption(tr("Save file as..."));
-  fd.setMode(QFileDialog::AnyFile);
-  QStringList filters;
-  filters.append("XDrawChem native (*.xdc)");
-  filters.append("MDL Molfile (*.mol)");
-  filters.append("CML - Chemical Markup Language (*.cml)");
-  //filters.append("ChemDraw binary format (*.cdx)");
-  filters.append("ChemDraw XML (*.cdxml)");
-  //filters.append("Encapsulated PostScript (*.eps)");
-  fd.setFilters(filters);  
-  if ( fd.exec() == QDialog::Accepted ) {
-    filename = fd.selectedFile();
-    QString tmpx = filename.right(4).lower();
-    if ( (tmpx != QString(".xdc")) &&
-	 (tmpx != QString(".mol")) &&
-	 (tmpx != QString(".cdx")) &&
-	 (tmpx != QString("dxml")) &&
-	 (tmpx != QString(".cml")) ) {
-      if (fd.selectedFilter().left(3) == QString("XDr"))
-	filename.append(".xdc");
-      if (fd.selectedFilter().left(3) == QString("MDL"))
-	filename.append(".mol");
-      if (fd.selectedFilter().left(3) == QString("CML"))
-	filename.append(".cml");
-      if (fd.selectedFilter().left(12) == QString("ChemDraw bin"))
-	filename.append(".cdx");
-      if (fd.selectedFilter().left(12) == QString("ChemDraw XML"))
-	filename.append(".cdxml");
-    }
-    save();
-  }
-  */
 }
 
 void ApplicationWindow::savePicture()
@@ -1648,7 +1673,7 @@ void ApplicationWindow::HelpTopic(QString topic) {
 
 // new manual (based on QTextBrowser) -- derived from Qt example "helpviewer"
 /****************************************************************************
-** $Id: application.cpp,v 1.44 2005/07/10 01:32:44 bherger Exp $
+** $Id: application.cpp,v 1.46 2005/11/16 03:01:55 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
