@@ -21,17 +21,17 @@ using std::endl;
 #include "bond.h"
 
 #include "ioiface.h"
-#include "mol.h"
 
 using namespace std;
 using namespace OpenBabel;
 
 // OpenBabel functions.
 void ApplicationWindow::OBGetFilters() {
-  io_type inFileType = UNDEFINED;
-  int i;
-  OBFileFormat fileFormat;
-  QString str1;
+  OBConversion Conv;
+  //io_type inFileType = UNDEFINED;
+  //int i;
+  //OBFileFormat fileFormat;
+  QString str1, myext;
   str1 = tr("--Select a filter-- (*)");
   readFilters.append(str1);
   writeFilters.append(str1);
@@ -44,20 +44,26 @@ void ApplicationWindow::OBGetFilters() {
   str1 = tr("XDC - XDrawChem native format (*)");
   readFilters.append(str1);
   writeFilters.append(str1);
-  for (i = 0; i < extab.Count(); i++) {
-    str1 = "";
-    str1.append(extab.GetExtension(i));
-    str1.append(": ");
-    str1.append(extab.GetDescription(i));
-    str1.append(" (*)");
-    filters.append(str1);
-    if (extab.IsReadable(i)) {
-      readFilters.append(str1);
+
+  Formatpos pos;
+  OBFormat* pFormat;
+  const char* str=NULL;
+  while(OBConversion::GetNextFormat(pos,str,pFormat))
+    {
+      //std::cout << "  " << str << std::endl;
+      if((pFormat->Flags() & NOTWRITABLE) && (pFormat->Flags() & NOTREADABLE))
+	continue;
+      str1 = str;
+      myext = str1.left( str1.find(" -- ") );
+      str1.append("(*.");
+      str1.append(myext);
+      str1.append(")");
+      if ( (pFormat->Flags() & NOTREADABLE) == 0 )
+	readFilters.append(str1);
+      if ( (pFormat->Flags() & NOTWRITABLE) == 0 )
+	writeFilters.append(str1);
     }
-    if (extab.IsWritable(i)) {
-      writeFilters.append(str1);
-    }
-  }
+  
   filters.sort();
   readFilters.sort();
   writeFilters.sort();
@@ -74,12 +80,15 @@ void ApplicationWindow::OBImport() {
 }
 
 void ApplicationWindow::OBNewLoad(QString infile, QString infilter) {
-  io_type inFileType = UNDEFINED;
-  OBFileFormat fileFormat;
+  //io_type inFileType = UNDEFINED;
+  ///OBFileFormat fileFormat;
+
+  OBConversion Conv;
+  OBFormat *inFormat = NULL;
 
   if (infilter.left(2) == "--") {
-    infilter = OBGuessFileType(infile);
-    if (infilter.left(2) == "--") {
+    inFormat = Conv.FormatFromExt(infile);
+    if (inFormat == NULL) {
       QMessageBox::warning( 0, tr("Could not determine file type"),
 			    tr("Please select a file type from the list.") );
       return;
@@ -87,6 +96,8 @@ void ApplicationWindow::OBNewLoad(QString infile, QString infilter) {
   }
   filename = infile;
   filefilter = infilter;
+
+  /* handled internally */
   if ( (infilter.left(3) == "XDC") || (infilter.left(3) == "CDX") ) {
     QString realFileName = filename;
       
@@ -112,22 +123,26 @@ void ApplicationWindow::OBNewLoad(QString infile, QString infilter) {
     r->repaint(false);      
     return;
   }
-  int cutpt = infilter.find(':');
+  /* end XDC/CDX code */
+  /* rest done by OpenBabel */
+
+  int cutpt = infilter.find(" -- ");
   infilter.truncate(cutpt);
   const char *tmpchar = infilter.latin1();
   char *realchar;
   realchar = (char*)malloc(sizeof(char)*infilter.length());
   strcpy(realchar, tmpchar);
-  inFileType = extab.FilenameToType( realchar );
-  OBMol *mol = new OBMol( inFileType, inFileType );
+  if (inFormat == NULL)
+    inFormat = Conv.FindFormat( realchar );
+  OBMol *mol = new OBMol;
   ifstream inFileStream( infile.latin1() );
-  if (!inFileStream)
-    {
-      QMessageBox::warning( 0, tr("Problem while opening the file"),
-			    tr("Cannot open the specified file.") );
-      return;
-    }
-  fileFormat.ReadMolecule(inFileStream, *mol, infile.latin1() );
+  if (!inFileStream) {
+    QMessageBox::warning( 0, tr("Problem while opening the file"),
+			  tr("Cannot open the specified file.") );
+    return;
+  }
+  Conv.SetInAndOutFormats(inFormat,inFormat);
+  Conv.Read(mol, &inFileStream);
   SelectAll();
   Clear();
   IOIface converter(c, mol);
@@ -142,10 +157,10 @@ void ApplicationWindow::OBNewLoad(QString infile, QString infilter) {
 
 void ApplicationWindow::OBExport() {
   cout << "OBExport()" << endl;
-  io_type inFileType = UNDEFINED;
+  //io_type inFileType = UNDEFINED;
   int i;
-  OBFileFormat fileFormat;
-  char *formatOptions;
+  //OBFileFormat fileFormat;
+  //char *formatOptions;
   QFile ftest;
 
   QFileDialog fd(QString::null, QString::null, 0, 0, TRUE);
@@ -159,14 +174,6 @@ void ApplicationWindow::OBExport() {
       if (i == QMessageBox::Cancel) return;
     }
     str1 = fd.selectedFilter();
-    if (str1.left(2) == "--") {
-      str1 = OBGuessFileType(fd.selectedFile());
-      if (str1.left(2) == "--") {
-	QMessageBox::warning( 0, tr("Could not determine file type"),
-			      tr("Please select a file type from the list.") );
-	return;
-      }
-    }
     filefilter = str1; // so we know what file type to save as
     filename = fd.selectedFile();
     OBNewSave();
@@ -176,11 +183,23 @@ void ApplicationWindow::OBExport() {
 void ApplicationWindow::OBNewSave() {
   c->StartUndo();  // needed in case we scale before saving
 
+  OBConversion Conv;
+  OBFormat *outFormat = NULL;
+
+  if (filefilter.left(2) == "--") {
+    outFormat = Conv.FormatFromExt( filefilter.latin1() );
+    if (outFormat == NULL) {
+      QMessageBox::warning( 0, tr("Could not determine file type"),
+			    tr("Please select a file type from the list.") );
+      return;
+    }
+  }
+  
   QString str1;
-  io_type inFileType = UNDEFINED;
-  int i;
-  OBFileFormat fileFormat;
-  char *formatOptions;
+  //io_type inFileType = UNDEFINED;
+  //int i;
+  //OBFileFormat fileFormat;
+  //char *formatOptions;
   str1 = filefilter;
 
   if (str1.left(3) == "XDC") {
@@ -205,19 +224,21 @@ void ApplicationWindow::OBNewSave() {
     statusBar()->message( tr( "Saved file ") + filename );
     return;
   }
-  int cutpt = str1.find(':');
+  int cutpt = str1.find(" -- ");
   str1.truncate(cutpt);
   const char *tmpchar = str1.latin1();
   char *realchar;
   realchar = (char*)malloc(sizeof(char)*str1.length());
   strcpy(realchar, tmpchar);
-  inFileType = extab.FilenameToType( realchar );
-  OBMol *mol = new OBMol( inFileType, inFileType );
-  
+  if (outFormat == NULL)
+    outFormat = Conv.FindFormat( realchar );
+  OBMol *mol = new OBMol;
+  Conv.SetInAndOutFormats(outFormat,outFormat);
+
   // invert so save file has correct coordinates
-  r->SelectAll();
-  r->Flip(FLIP_V);
-  r->DeselectAll();
+  //r->SelectAll();
+  //r->Flip(FLIP_V);
+  //r->DeselectAll();
 
   IOIface converter(c, mol);
   if ( !converter.convertToOBMol() ) {
@@ -227,16 +248,18 @@ void ApplicationWindow::OBNewSave() {
   }
   ofstream outFileStream( filename.latin1() );
   if (!outFileStream)
-    {
-      QMessageBox::warning( 0, tr("Problem while writing the file"),
-			    tr("Cannot write the specified file.") );
-      return;
-    }
-  fileFormat.WriteMolecule(outFileStream, *mol, "3D", formatOptions);
+  {
+  QMessageBox::warning( 0, tr("Problem while writing the file"),
+  tr("Cannot write the specified file.") );
+  return;
+  }
+  
+  Conv.Write(mol, &outFileStream);
+  //fileFormat.WriteMolecule(outFileStream, *mol, "3D", formatOptions);
   setCaption( QString(XDC_VERSION) + QString(" - ") + filename );
   
   statusBar()->message( tr( "Saved file ") + filename );
-  c->Undo();
+  //c->Undo();
 }
 
 QString ApplicationWindow::OBGuessFileType(QString guessname) {
