@@ -8,6 +8,7 @@
 #include "render2d.h"
 #include "drawable.h"
 #include "dpoint.h"
+#include "moldata.h"
 
 #define BOND_LEFT 0
 #define BOND_RIGHT 1
@@ -32,13 +33,16 @@ class Bond : public Drawable {
   bool Equals(Bond *);
   bool WithinRect(QRect, bool);
   int Order() { return order; }
+  int baseOrder() {
+    if (order == 5) return 1;
+    if (order == 7) return 1;
+    return order;
+  }
   void setOrder(int);
   int Stereo() { return stereo; }
   void setStereo(int a) { stereo = a; }
   int Dash() { return dashed; }
   void setDash(int d) { dashed = d; }
-  int Thick() { return thick; }
-  void setThick(int t) { thick = t; }
   QRect BoundingBox();
   DPoint *otherPoint(DPoint *);
   void setIR_shift(double in1) { IR_shift = in1; }
@@ -51,6 +55,39 @@ class Bond : public Drawable {
   int getDoubleBondAlign() { return wside; }
   void setDoubleBondAuto(int db1) { auto_wside = db1; }
   int getDoubleBondAuto() { return auto_wside; }
+  void resetReactions() { partial_charge = -999.0; rxnlist = "NONE"; }
+  void setPC(double x1) { partial_charge = x1; }
+  double getPC() { return partial_charge; }
+  void setReactions(QString rxn1) { rxnlist = rxn1; }
+  QString getReactions() { return rxnlist; }
+  void setCName(QString cn1) { cname = cn1; }
+  QString CName() { return cname; }
+  bool isCHBond() {
+    if (start->element == "H") return true;
+    if (end->element == "H") return true;
+    return false;
+  }
+  bool aromatic() {
+    if ( (start == 0) || (end == 0) ) {
+      return false;
+    }
+    if (start->aromatic && end->aromatic)
+      return true;
+    return false;
+  }
+  double length() {
+    int e1, e2;
+    e1 = start->getAtomicNumber();
+    e2 = end->getAtomicNumber();
+    return MolData::bondLength(e1, e2, order);
+  }
+  QPoint midpoint() {
+    double dx, dy;
+    dx = ( end->x + start->x ) / 2.0;
+    dy = ( end->x + start->x ) / 2.0;
+    QPoint mp1( (int)dx, (int)dy );
+    return mp1;
+  }
  private:
   // Renderer
   Render2D *r;
@@ -62,8 +99,6 @@ class Bond : public Drawable {
   int stereo;
   // is one or more of the lines dashed
   int dashed;
-  // thickness of bond
-  int thick;
   // which side to draw double bond on?
   // standing at start and looking at end
   // 0 = left, 2 = center, 1 = right; see #define's above
@@ -72,6 +107,11 @@ class Bond : public Drawable {
   // IR data
   double IR_shift;
   QString IR_intensity;
+  // reactivity
+  double partial_charge;
+  QString rxnlist;
+  // bond name
+  QString cname;
 };
 
 #endif
