@@ -25,9 +25,6 @@
  * accompanying this package.
  */
 
-#include <qstring.h>
-#include <qlist.h>
-
 #include "boshcp.h"
 
   void BremserOneSphereHOSECodePredictor::prepareHashTable()
