@@ -20,6 +20,8 @@ Bracket::Bracket(Render2D *r1, QObject *parent, const char *name)
   highlighted = false;
   style = BRACKET_SQUARE;
   subtext = "";
+  fill = false;
+  fillColor = QColor(0,255,255);
 }
 
 QString Bracket::ToXML(QString xml_id) {
@@ -73,6 +75,24 @@ QString Bracket::ToXML(QString xml_id) {
   s.append(n1);
   s.append("</color>\n");
 
+  // fill info
+  s.append("<fill>");
+  if (fill == true)
+    s.append("true");
+  else
+    s.append("false");
+  s.append("</fill>");
+  s.append("<fillcolor>");
+  n1.setNum(fillColor.red());
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(fillColor.green());
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(fillColor.blue());
+  s.append(n1);
+  s.append("</fillcolor>\n");
+
   // end bracket
   s.append("</bracket>\n");
 
@@ -136,16 +156,50 @@ void Bracket::FromXML(QString xml_tag) {
     i2 = xml_tag.find("</color>") + 8;
     SetColorFromXML(xml_tag.mid(i1, i2 - i1));
   }
+  i1 = xml_tag.find("<fill>");
+  if (i1 >= 0) {
+    if ( xml_tag.mid(i1 + 6, 4) == "true" )
+      fill = true;
+    else
+      fill = false;
+  }
+  i1 = xml_tag.find("<fillcolor>");
+  if (i1 >= 0) {
+    i2 = xml_tag.find("</fillcolor>") + 12;
+    SetFillColorFromXML(xml_tag.mid(i1, i2 - i1));
+  }
+}
+
+void Bracket::SetFillColorFromXML(QString xml_tag) {
+  cout << "SetFColorFromXML:" << xml_tag << endl;
+  int i1, i2;
+  int d1, d2, d3;
+
+  i1 = xml_tag.find("<fillcolor>");
+  i2 = xml_tag.find("</fillcolor>");
+  xml_tag.remove(i2, 999);
+  xml_tag.remove(i1, 11);
+
+  QTextStream ts(&xml_tag, IO_ReadOnly);
+
+  ts >> d1 >> d2 >> d3;
+
+  fillColor = QColor(d1, d2, d3);
 }
 
 void Bracket::Render(void)
 {
-  QColor c1;
+  QColor c1, ivc;
   if (highlighted)
     c1 = QColor(255,0,0);
   else
     c1 = color;
-  r->drawBracket( start->toQPoint(), end->toQPoint(), c1, style );
+  // safety check
+  if ( (fill == true) && (fillable() == true) ) {
+    ivc = fillColor;
+    // otherwise, it's invalid
+  }
+  r->drawBracket( start->toQPoint(), end->toQPoint(), c1, style, ivc );
   int tx = end->toQPoint().x(), ty = end->toQPoint().y();
   tx += 4;
   if (subtext.length() > 0)
