@@ -29,11 +29,23 @@ class Bracket : public Drawable {
   void SetStyle(int s1) { style = s1; }
   void setText(QString s1) { subtext = s1; }
   QString getText() { return subtext; }
+  void setFill(bool b1) { fill = b1; }
+  bool getFill() { return fill; }
+  void setFillColor(QColor fc1) { fillColor = fc1; }
+  QColor getFillColor() { return fillColor; }
+  void SetFillColorFromXML(QString);
+  bool fillable() {
+    if (style > 3) return true;  // see defs.h for BRACKET_<types>
+    return false;
+  }
  private:
   // Renderer
   Render2D *r;
   // subscript text, if applicable
   QString subtext;
+  // fill options, where applicable
+  bool fill;
+  QColor fillColor;
 };
 
 #endif
