@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 using std::cout;
 using std::endl;
@@ -13,6 +13,7 @@ using std::endl;
 #include "bracket.h"
 #include "text.h"
 #include "symbol.h"
+#include "biotools.h"
 #include "chemdata.h"
 #include "defs.h"
 
@@ -21,6 +22,7 @@ using std::cout;
 ChemData::ChemData(QObject *parent, const char *name)
   : QObject(parent, name)
 {
+  thick_kludge = -1;
 }
 
 void ChemData::drawAll() {
@@ -204,8 +206,8 @@ Drawable * ChemData::FindNearestObject(DPoint *target, double &dist) {
 }
 
 void ChemData::Erase(Drawable *d) {
-  QList<Drawable> removelist;
-  QList<Molecule> split_list;
+  QPtrList<Drawable> removelist;
+  QPtrList<Molecule> split_list;
   bool erased = false;
 
   if (drawlist.remove(d) == false) {
@@ -232,7 +234,7 @@ void ChemData::Erase(Drawable *d) {
 
 void ChemData::EraseSelected() {
   Molecule *m;
-  QList<Drawable> removelist;
+  QPtrList<Drawable> removelist;
 
   for (tmp_draw = drawlist.first(); tmp_draw != NULL; 
        tmp_draw = drawlist.next()) {
@@ -269,8 +271,8 @@ void ChemData::EraseSelected() {
 
 // Split Molecule's which hold multiple structures (e.g. after delete)
 void ChemData::DetectSplit() {
-  QList<Drawable> removelist;
-  QList<Molecule> split_list;
+  QPtrList<Drawable> removelist;
+  QPtrList<Molecule> split_list;
   Molecule *tmp_mol;
   Drawable *td2;
 
@@ -298,7 +300,7 @@ void ChemData::DetectSplit() {
 }
 
 void ChemData::SelectAll(void) {
-  QList<DPoint> allpts = UniquePoints();
+  QPtrList<DPoint> allpts = UniquePoints();
 
   for (tmp_draw = drawlist.first(); tmp_draw != NULL; 
        tmp_draw = drawlist.next()) {
@@ -310,7 +312,7 @@ void ChemData::SelectAll(void) {
 }
 
 void ChemData::DeselectAll(void) {
-  QList<DPoint> allpts = UniquePoints();
+  QPtrList<DPoint> allpts = UniquePoints();
 
   for (tmp_draw = drawlist.first(); tmp_draw != NULL; 
        tmp_draw = drawlist.next()) 
@@ -378,7 +380,7 @@ QRect ChemData::selectionBox() {
 // box changes.  This function is called to start checking whether objects
 // fall within the select box.
 void ChemData::NewSelectRect(QRect n, bool shiftdown) {
-  QList<DPoint> allpts = UniquePoints();
+  QPtrList<DPoint> allpts = UniquePoints();
 
   for (tmp_pt = allpts.first(); tmp_pt != NULL; tmp_pt = allpts.next()) {
     if (n.contains(tmp_pt->toQPoint()) == true) {
@@ -395,8 +397,8 @@ void ChemData::NewSelectRect(QRect n, bool shiftdown) {
 }
 
 // Get list of unique points contained in all Molecules.
-QList<DPoint> ChemData::UniquePoints() {
-  QList<DPoint> up, tp;
+QPtrList<DPoint> ChemData::UniquePoints() {
+  QPtrList<DPoint> up, tp;
 
   for (tmp_draw = drawlist.first(); tmp_draw != NULL; 
        tmp_draw = drawlist.next()) {
@@ -409,8 +411,8 @@ QList<DPoint> ChemData::UniquePoints() {
   return up;
 }
 
-QList<Drawable> ChemData::UniqueObjects() {
-  QList<Drawable> uo, to;
+QPtrList<Drawable> ChemData::UniqueObjects() {
+  QPtrList<Drawable> uo, to;
   Drawable *td2;
 
   for (tmp_draw = drawlist.first(); tmp_draw != NULL; 
