@@ -1,7 +1,7 @@
 #include <iostream>
 #include <qstring.h>
 #include <qstringlist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qtextstream.h>
 #include <qfile.h>
 #include <qdatetime.h>
@@ -33,11 +33,18 @@ bool ChemData::NewLoadCMLFile(QString fn) {
   // add bonds and labels to main drawing
   double totlen = 0.0, dx = 99999.0, dy = 99999.0;
   int n = 0;
-  QList<Bond> parsedBonds;
+  int th1;
+  std::cout << "thick_kludge: " << thick_kludge << std::endl;
+  if (thick_kludge > 0) {
+    th1 = thick_kludge;
+  } else {
+    th1 = 1;
+  }
+  QPtrList<Bond> parsedBonds;
   Bond *tbond;
   parsedBonds = handler.getBonds();
   for (tbond = parsedBonds.first(); tbond != 0; tbond = parsedBonds.next()) {
-    addBond(tbond->Start(), tbond->End(), 1, tbond->Order(), QColor(0,0,0),
+    addBond(tbond->Start(), tbond->End(), th1, tbond->Order(), QColor(0,0,0),
 	    true);
     if (tbond->Start()->x < dx) dx = tbond->Start()->x;
     if (tbond->End()->x < dx) dx = tbond->End()->x;
@@ -46,7 +53,7 @@ bool ChemData::NewLoadCMLFile(QString fn) {
     totlen += tbond->Start()->distanceTo(tbond->End());
     n++;
   }
-  QList<DPoint> parsedPoints;
+  QPtrList<DPoint> parsedPoints;
   parsedPoints = handler.getPoints();
   QString makesub, ms2;
   for (tmp_pt = parsedPoints.first(); tmp_pt != 0; 
@@ -393,9 +400,16 @@ void ChemData::Convert_CML_Lists_To_Native() {
   double totlen = 0.0;
   int n = 0;
   QString makesub, ms2;
+  int th1;
+  std::cout << "thick_kludge: " << thick_kludge << std::endl;
+  if (thick_kludge > 0) {
+    th1 = thick_kludge;
+  } else {
+    th1 = 1;
+  }
 
   // convert CML_Atoms to DPoints
-  QList<DPoint> points;
+  QPtrList<DPoint> points;
   for (tmp_atom = CML_Atoms.first(); tmp_atom != NULL; 
        tmp_atom = CML_Atoms.next()) {
     points.append(tmp_atom->toDPoint());
@@ -420,7 +434,7 @@ void ChemData::Convert_CML_Lists_To_Native() {
 	break;
       }
     }
-    addBond(end1, end2, 1, tmp_bond->order, QColor(0,0,0), true);
+    addBond(end1, end2, th1, tmp_bond->order, QColor(0,0,0), true);
     totlen += end1->distanceTo(end2);
     n++;
   }
@@ -477,8 +491,8 @@ void ChemData::Convert_CML_Lists_To_Native() {
 
 // Save CML format
 bool ChemData::save_cml(QString fn) {
-  QList<DPoint> up;
-  QList<Drawable> uo;
+  QPtrList<DPoint> up;
+  QPtrList<Drawable> uo;
   Text *tmp_text;
   Bond *tmp_bond;
   QString n1, nfull;
