@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 using std::cout;
@@ -37,8 +37,8 @@ void ChemData::Cut() {
 }
 
 void ChemData::Copy() {
-  QList<Drawable> unique;
-  QList<DPoint> oldPoints, newPoints;
+  QPtrList<Drawable> unique;
+  QPtrList<DPoint> oldPoints, newPoints;
   Drawable *td2, *tdx;
   DPoint *n;
 
@@ -78,8 +78,8 @@ void ChemData::Copy() {
 
 bool ChemData::Paste() {
   DeselectAll();
-  QList<DPoint> oldPoints;
-  QList<DPoint> newPoints;
+  QPtrList<DPoint> oldPoints;
+  QPtrList<DPoint> newPoints;
   DPoint *n;
   Bond *b;
   Text *ot, *t;
