@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 using std::cerr;
 using std::endl;
@@ -27,10 +27,11 @@ void ChemData::XDCEventHandler(XDC_Event *evt) {
   switch (evt->type()) {
   case EVT_ADD_BOND:
     if (evt->Param2() < 0)
-      addBond( evt->Start(), evt->End(), evt->Param1(), 1, evt->color() );
+      addBond( evt->Start(), evt->End(), evt->Param1(), 1, evt->color(),  
+	       evt->bool1() );
     else
       addBond( evt->Start(), evt->End(), evt->Param1(), evt->Param2(), 
-	       evt->color() );
+	       evt->color(), evt->bool1() );
     break;
   case EVT_ADD_BOND_UP:
     addBond( evt->Start(), evt->End(), 1, 5, evt->color() );
