@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qtextstream.h>
 #include <qfile.h>
 
