@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qtextstream.h>
 #include <qmessagebox.h>
 #include <qfile.h>
@@ -89,13 +89,13 @@ bool ChemData::load_legacy(QString fn) {
   QTextStream t(&f);
   QString ln, dummy, tmpline;
   int i1, i2, i3, i4, i5;
-  QList<DPoint> points;
+  QPtrList<DPoint> points;
   DPoint *tp;
   Text *mt;
 
   do {
     ln = t.readLine();
-    // read POINTs into QList points (hopefully all at beginning of file :)
+    // read POINTs into QPtrList points (hopefully all at beginning of file :)
     if (ln.left(5) == QString("POINT")) {
       tp = new DPoint;
       QTextIStream(&ln) >> dummy >> i1 >> tp->x >> tp->y >> i2 >> i3;
