@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qmessagebox.h>
 #include <qstringlist.h>
 
@@ -22,8 +22,8 @@ using std::endl;
 using std::cout;
 
 void ChemData::ReactionAnalysis(int flags) {
-  QList<Molecule> reactantList;
-  QList<Molecule> productList;
+  QPtrList<Molecule> reactantList;
+  QPtrList<Molecule> productList;
   Tool_1HNMR_Dialog tool1hnmr;
   Tool_13CNMR_Dialog tool13cnmr;
 
