@@ -178,11 +178,7 @@ void ChemData::Tool(DPoint *target, int mode) {
     QMessageBox::information(r, tr("Octanol-water partition"), tr("Estimated octanol-water partition constant (log Kow) = %1").arg(kow) );
     break;
   case MODE_TOOL_2D3D:
-    //tool2d3d.setMolecule(m);
-    //na.get3DMol( m->ToMDLMolfile() );
     m->Make3DVersion();
-    //std::cout << m->ToMDLMolfile() << std::endl;
-    //std::cout << na.s3dmol << std::endl;
     break;
   case MODE_TOOL_NAME:
     m->CalcName();
@@ -324,7 +320,7 @@ void ChemData::AutoLayout() {
 						   ns);
 	  int dx = tcenter.x() - amid.x();
 	  int dy = tcenter.y() - amid.y();
-	  double dist = sqrt(dx*dx + dy*dy);
+	  double dist = sqrt( (double)(dx*dx + dy*dy) );
 	  cout << dist << endl;
 	  if (dist < 25) {
 	    if (tmp_arrow->Orientation() == ARROW_HORIZONTAL) {
