@@ -2,7 +2,7 @@
 #define GRAPHDIALOG_H
 
 #include <qdialog.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 #include "graphdata.h"
 #include "graphwidget.h"
