@@ -4,7 +4,7 @@
 #define GRAPHWIDGET_H
 
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qprinter.h>
@@ -32,7 +32,7 @@ class GraphWidget : public QWidget {
  private:
   int datatype;
   int output;
-  QList<GraphData> peaks;
+  QPtrList<GraphData> peaks;
   QPixmap p1;
   QPrinter *printer;
 };
