@@ -24,7 +24,6 @@ using std::endl;
 
 #include "ioiface.h"
 #include "dpoint.h"
-#include "mol.h"
 #include "chemdata.h"
 #include "application.h"
 #include "bond.h"
@@ -185,23 +184,25 @@ void IOIface::convertToChemData() {
 
       text=new Text(chemdata->getRender2D());
       QString str=IOIface::symbol[atom1->GetAtomicNum()-1];
-      text->setText(str);
       text->setPoint(s);
-      str.fill(' ');
-      text->setTextMask(str);
+      text->setText(str);
+      //str.fill(' ');
+      //text->setTextMask(str);
       chemdata->addText(text);
+      //std::cout << "ioiface(1) text:" << str << std::endl;
     }
 
     if(!atom2->IsCarbon()) {
 
       text=new Text(chemdata->getRender2D());
       QString str=IOIface::symbol[atom2->GetAtomicNum()-1];
-      text->setText(str);
       text->setPoint(e);
-      str.fill(' ');
-      text->setTextMask(str);
+      text->setText(str);
+      //str.fill(' ');
+      //text->setTextMask(str);
       text->setJustify(JUSTIFY_CENTER);
       chemdata->addText(text);
+      //std::cout << "ioiface(2) text:" << str << std::endl;
 
     }
   }
@@ -241,6 +242,7 @@ bool IOIface::convertToOBMol() {
     atom.SetAtomicNum( tmp_atom->getAtomicNumber() );
     strcpy(type, tmp_atom->baseElement() );
     atom.SetType( type );
+    //atom.SetType( tmp_atom->baseElement().ascii() );
 
     if (!obmol->AddAtom(atom))
       return(false);
