@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: main.cpp,v 1.4 2004/06/08 01:22:45 bherger Exp $
+** $Id: main.cpp,v 1.6 2005/02/09 00:59:36 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -154,7 +154,7 @@ int main( int argc, char ** argv ) {
   if (to3dflag) {
     mw->ni_savefile = outfile;
     mw->ni_tflag = tflag;
-    QTimer::singleShot(0, mw, SLOT(SavePNG()) );
+    QTimer::singleShot(0, mw, SLOT(Save3D()) );
   }
 
   if (quitflag) exit(0);  // exit if non-interactive mode.
@@ -181,6 +181,7 @@ void usage() {
   cout << "Command line options:" << endl;
   cout << "-png <output file>: Create a PNG image of input file and exit" << endl;
   cout << "-t: Make transparent PNG (also specify -png)" << endl;
+  cout << "-3d: Make 3D model of input file (output MDL mofile)" << endl;
   cout << "-h, --help:  Display this help" << endl;
   cout << "-v, --version:  Display the version information" << endl;
   
