@@ -1,7 +1,7 @@
 // molecule.cpp - Molecule's implementation of functions
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qfont.h>
 #include <qpoint.h>
 #include <qtextstream.h>
@@ -45,7 +45,7 @@ void Molecule::Render(void)
   Bond *tb2;
   int nleft = 0, nright = 0;
   double ang;
-  QListIterator<Bond> it(bonds);
+  QPtrListIterator<Bond> it(bonds);
   for ( ; it.current(); ++it ) {
     tb2 = it.current();
     if (tb2->Order() == 2) {
@@ -235,12 +235,12 @@ bool Molecule::WithinBounds(DPoint *target) {
 // Determine if split is necessary (e.g., if this structure contains two
 // or more fragments).  Return empty list if not, return new Molecule's 
 // if needed
-QList<Molecule> Molecule::MakeSplit() {
-  QList<DPoint> up;
-  QList<DPoint> pointqueue;
-  QList<Bond> uo;
-  QList<Bond> removequeue;
-  QList<Molecule> molecules;
+QPtrList<Molecule> Molecule::MakeSplit() {
+  QPtrList<DPoint> up;
+  QPtrList<DPoint> pointqueue;
+  QPtrList<Bond> uo;
+  QPtrList<Bond> removequeue;
+  QPtrList<Molecule> molecules;
   Molecule *nm;
   DPoint *current;
 
@@ -303,8 +303,8 @@ QList<Molecule> Molecule::MakeSplit() {
 }
 
 // Create and return a list of all unique DPoint's in this Molecule
-QList<DPoint> Molecule::AllPoints() {
-  QList<DPoint> pl;
+QPtrList<DPoint> Molecule::AllPoints() {
+  QPtrList<DPoint> pl;
 
   for (tmp_bond = bonds.first(); tmp_bond != NULL; tmp_bond = bonds.next()) {
     tmp_pt = tmp_bond->Start();
@@ -341,8 +341,8 @@ QList<DPoint> Molecule::AllPoints() {
 }
 
 // Create and return a list of all unique Drawable's in this Molecule
-QList<Drawable> Molecule::AllObjects() {
-  QList<Drawable> dl;
+QPtrList<Drawable> Molecule::AllObjects() {
+  QPtrList<Drawable> dl;
 
   up = AllPoints();
 
@@ -358,7 +358,7 @@ QList<Drawable> Molecule::AllObjects() {
   return dl;
 }
 
-QList<Bond> Molecule::AllBonds() {
+QPtrList<Bond> Molecule::AllBonds() {
   // this should be safe, right?  ioiface.cpp should use this read-only...  :)
   return bonds;
 }
@@ -558,6 +558,10 @@ void Molecule::addBond(DPoint *s, DPoint *e, int thick, int order,
   Bond *b = new Bond(r);
   b->setPoints(s, e);
   b->setThick(thick);
+  if (preferences.getBondCenter() == true) {
+    b->setDoubleBondAuto(0);
+    b->setDoubleBondAlign(2);
+  }
   if (order != 99) {
     b->setOrder(order);
   } else {
@@ -671,9 +675,9 @@ bool Molecule::Erase(Drawable *d) {
 
 // Erase selected items
 void Molecule::EraseSelected() {
-  QList<Bond> removebonds;
-  QList<Text> removetext;
-  QList<Symbol> removesym;
+  QPtrList<Bond> removebonds;
+  QPtrList<Text> removetext;
+  QPtrList<Symbol> removesym;
 
   for (tmp_bond = bonds.first(); tmp_bond != NULL; tmp_bond = bonds.next()) {
     if (tmp_bond->Highlighted() == true) {
@@ -715,8 +719,8 @@ void Molecule::EraseSelected() {
 QString Molecule::ToXML(QString xml_id) {
   QString s("");
 
-  QList<DPoint> up;
-  QList<Drawable> uo;
+  QPtrList<DPoint> up;
+  QPtrList<Drawable> uo;
   Drawable *tmp_draw;
   QString n1, nfull;
   int n = 0;
@@ -733,7 +737,7 @@ QString Molecule::ToXML(QString xml_id) {
     if (tmp_draw->Type() == TYPE_TEXT) {
       tmp_text = (Text *)tmp_draw;  // is this cheating?
       tmp_text->Start()->element = tmp_text->getText();
-      tmp_text->Start()->elementmask = tmp_text->getTextMask();
+      tmp_text->Start()->elementmask = tmp_text->getRichText();
       tmp_text->Start()->color = tmp_text->GetColor();
       tmp_text->Start()->font = tmp_text->getFont();
       tmp_text->Start()->hit = true;
@@ -771,7 +775,7 @@ QString Molecule::ToXML(QString xml_id) {
     s.append("<elemask>");
     s.append(tmp_pt->elementmask);
     s.append("</elemask>\n");
-    if (tmp_pt->hit) s.append("<textobject>yes</textobject>");
+    if (tmp_pt->hit) s.append("<textobject>yes</textobject>\n");
     if (tmp_pt->symbol.length() > 1) {
       s.append("<symtype>");
       s.append(tmp_pt->symbol);
@@ -859,8 +863,8 @@ QString Molecule::ToXML(QString xml_id) {
 // XML (ChemDraw(TM) format) representation of this Molecule
 QString Molecule::ToCDXML(QString xml_id) {
   QString s("");
-  QList<DPoint> up;
-  QList<Drawable> uo;
+  QPtrList<DPoint> up;
+  QPtrList<Drawable> uo;
   Drawable *tmp_draw;
   QString n1, nfull;
   int n = xml_id.toInt() + 1;
@@ -940,8 +944,8 @@ QString Molecule::ToCDXML(QString xml_id) {
 
 // Generate MDL Molfile to export to generate SMILES, export for 3-D 
 QString Molecule::ToMDLMolfile(int coords) {
-  QList<DPoint> up;
-  QList<Drawable> uo;
+  QPtrList<DPoint> up;
+  QPtrList<Drawable> uo;
   Bond *tmp_bond;
   QString tmpline;
   int acount = 0, bcount = 0;
@@ -1004,13 +1008,15 @@ QString Molecule::ToMDLMolfile(int coords) {
     if (tmp_bond->Order() == 7)
       t << "  6  0  0  0" << endl;
   }
+
+  t << "M  END" << endl;
   
   return molfile;
 }
 
 void Molecule::FromXML(QString xml_tag) {
   QString bondtag, subtag, startid, endid;
-  QList<DPoint> points;
+  QPtrList<DPoint> points;
   DPoint *s1, *e1;
   int i1, i2;
 
@@ -1117,7 +1123,7 @@ void Molecule::FromXML(QString xml_tag) {
       tmp_text->setPoint(tmp_pt);
       tmp_text->SetColor(tmp_pt->color);
       tmp_text->setFont(tmp_pt->font);
-      tmp_text->setText(tmp_pt->element);
+      tmp_text->setText(tmp_pt->elementmask);
       if (tmp_pt->elementmask.length() > 0) {
 	tmp_text->setTextMask(tmp_pt->elementmask);
       } else {
