@@ -9,7 +9,8 @@
 using std::cout;
 using std::endl;
 
-#include "mol.h"
+#include <openbabel/mol.h>
+#include <openbabel/obconversion.h>
 
 using namespace OpenBabel;
 
