@@ -1,7 +1,7 @@
 // molecule_1h_nmr.cpp - Molecule's implementation of (more) functions
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qregexp.h>
 #include <qmessagebox.h>
@@ -145,10 +145,10 @@ void Molecule::RemoveNMRprotons() {
 // Do depth-first search to identify magnetic environment
 // Essentially, assign a HOSE-style code to each proton.
 void Molecule::ProtonEnvironment() {
-  QListIterator<DPoint> it(up);
+  QPtrListIterator<DPoint> it(up);
   int adj_protons;
   DPoint *depth1_pt, *depth2_pt, *depth3_pt;
-  QList<DPoint> search_stack; // depth 2 atoms
+  QPtrList<DPoint> search_stack; // depth 2 atoms
   QString nearest, r1, r2, r3, r_current, depth3_str;
   QStringList rgroups, depth3list;
   int rnext = 0;
@@ -256,12 +256,12 @@ void Molecule::ProtonEnvironment() {
 
 // Do depth-first search to find adjacent protons (H at depth 2 and 3)
 void Molecule::Multiplicity_1HNMR() {
-  QListIterator<DPoint> it(up);
+  QPtrListIterator<DPoint> it(up);
   int adj_protons;
   bool split, chiral;
   DPoint *depth1_pt, *depth2_pt, *depth3_pt;
   QString new_magenv;
-  QList<DPoint> search_stack; // depth 2 atoms
+  QPtrList<DPoint> search_stack; // depth 2 atoms
 
   for (tmp_pt = up.first(); tmp_pt != NULL; tmp_pt = up.next()) {
     // chiral atoms should implicitly be split...
