@@ -37,7 +37,7 @@ using std::vector;
 #include <sstream>
 #include <map>
 
-#include <mol.h>
+using namespace OpenBabel;
 
 // CleanUp(): Invoke SDG() to clean up structure
 void Molecule::CleanUp() {
@@ -176,12 +176,22 @@ QString Molecule::ToSMILES() {
   std::istringstream istream(molfile.latin1());
   std::ostringstream ostream;
 
+  /* obsolete? 
   OpenBabel::OBMol myMol(OpenBabel::SDF,OpenBabel::SMI);
   OpenBabel::OBFileFormat fileFormat;
 
   fileFormat.ReadMolecule(istream, myMol, "tmpname");
   fileFormat.WriteMolecule(ostream, myMol);
+  */
 
+  OBConversion Conv(&istream, &ostream);
+  OBFormat *pInFormat = NULL, *pOutFormat = NULL;
+
+  pInFormat = Conv.FindFormat("mol");
+  pOutFormat = Conv.FindFormat("smi");
+
+  Conv.SetInAndOutFormats(pInFormat, pOutFormat);
+  Conv.Convert();
 
   // convert the string into a terminated c string
 
@@ -195,10 +205,20 @@ QString Molecule::ToSMILES() {
 void Molecule::FromSMILES(QString sm) {
 
   std::istringstream istream(sm.latin1()); // build a stream on the string
+
+  /* obsolete?
   OpenBabel::OBMol myMol(OpenBabel::SMI, OpenBabel::SDF);
   OpenBabel::OBFileFormat fileFormat;
 
   fileFormat.ReadMolecule(istream, myMol, "tmpname");
+  */
+  
+  OBMol myMol;
+  OBConversion conv;
+  OBFormat *format = conv.FindFormat("smi");
+  conv.SetInAndOutFormats(format, format);
+  myMol.Clear();
+  conv.Read(&myMol, &istream);
 
   // now convert the molecule into XDC's internal representation
 
