@@ -56,7 +56,7 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
   }
 
   // identify aromatic rings (just benzene for now)
-  void SSSR::FindAromatic(QList<Bond> bl) {
+  void SSSR::FindAromatic(QPtrList<Bond> bl) {
     Bond *tmp_bond;
     bool o1, o2, goodring;
 
@@ -85,15 +85,15 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
   }
 
   // Make sssr from given 'atoms'
-  void SSSR::BuildSSSR(QList<DPoint> alist) {
+  void SSSR::BuildSSSR(QPtrList<DPoint> alist) {
     // clear old SSSR
     sssr.clear();
     sssr_data.clear();
 
     int atomsRemoved;
     structureAtoms = alist;
-    QListIterator<DPoint> it(structureAtoms);
-    QListIterator<DPoint> idel(structureAtoms);
+    QPtrListIterator<DPoint> it(structureAtoms);
+    QPtrListIterator<DPoint> idel(structureAtoms);
     // eliminate pesky chains by cutting off zero- and one-bond 'atoms'
     do {
       atomsRemoved = 0;
@@ -121,8 +121,8 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
     }        
     // find fused and bridged rings
     if (sssr.count() > 1) {
-      QListIterator<QList<DPoint> > sssr1(sssr);
-      QListIterator<QList<DPoint> > sssr2(sssr);
+      QPtrListIterator<QPtrList<DPoint> > sssr1(sssr);
+      QPtrListIterator<QPtrList<DPoint> > sssr2(sssr);
       int neighbors = 0, int1;
       bool bridged = false;
       for ( ; sssr1.current(); ++sssr1 ) {
@@ -139,7 +139,7 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
   }
 
   // Add to sssr.  Make sure this is not a duplicate of an existing ring
-  void SSSR::Add(QList<DPoint> *r1) {
+  void SSSR::Add(QPtrList<DPoint> *r1) {
     DPoint *flagpt;
     if (CheckRing(r1) == true) {
       sssr.append(r1);
@@ -152,8 +152,8 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
   }
 
   // number of points in common between two rings
-  int SSSR::CommonPoints(QList<DPoint> *r1, QList<DPoint> *r2) {
-    QListIterator<DPoint> i1(*r1);
+  int SSSR::CommonPoints(QPtrList<DPoint> *r1, QPtrList<DPoint> *r2) {
+    QPtrListIterator<DPoint> i1(*r1);
     int ol = 0;
     for ( ; i1.current(); ++i1) {
       if (r2->find(i1.current()) >= 0) ol++;
@@ -162,7 +162,7 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
   }
 
   // check if ring is already in SSSR
-  bool SSSR::CheckRing(QList<DPoint> *r) {
+  bool SSSR::CheckRing(QPtrList<DPoint> *r) {
     int l2;
     bool iflag = true;
     for (tmp_ring = sssr.first(); tmp_ring != NULL; tmp_ring = sssr.next() ) {
@@ -178,8 +178,8 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
 
   // Find smallest unique ring containing root node *root
   // Based on Figueras' breadth-first traversal
-  QList<DPoint> * SSSR::GetRing(DPoint *root) {
-    QList<DPoint> *testring = new QList<DPoint>;
+  QPtrList<DPoint> * SSSR::GetRing(DPoint *root) {
+    QPtrList<DPoint> *testring = new QPtrList<DPoint>;
     DPoint *thisnode;
     int tf = 0;
     ClearPaths();
@@ -203,8 +203,8 @@ int SSSR::InSameRing(DPoint *r1, DPoint *r2, DPoint *r3) {
 	} else { // collision
 	  cout << "collide" << endl << "thisnode(" << thisnode->serial <<"):";
 	  // merge path lists (note overlaps)
-	  QListIterator<DPoint> i(thisnode->path);
-	  QListIterator<DPoint> j(tmp_pt->path);
+	  QPtrListIterator<DPoint> i(thisnode->path);
+	  QPtrListIterator<DPoint> j(tmp_pt->path);
 	  for ( ; i.current(); ++i) {
 	    cout << i.current()->serial;
 	    testring->append(i.current());
