@@ -7,7 +7,7 @@
 #ifndef MOL_SSSR_H
 #define MOL_SSSR_H
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include "dpoint.h"
 
 class RingData {
@@ -19,26 +19,26 @@ class RingData {
 
 class SSSR {
 public:
-  QList<QList<DPoint> > sssr;
-  QList<RingData> sssr_data;
-  QList<DPoint> *tmp_ring;
+  QPtrList<QPtrList<DPoint> > sssr;
+  QPtrList<RingData> sssr_data;
+  QPtrList<DPoint> *tmp_ring;
   RingData *tmp_ringdata;
   DPoint *tmp_pt;
   DPoint *lastnode;  // 'source' node in BFS
   // Build SSSR from these lists
-  QList<DPoint> structureAtoms;
+  QPtrList<DPoint> structureAtoms;
   // BFS queue
-  QList<DPoint> bfs_queue;
+  QPtrList<DPoint> bfs_queue;
 
   int IsInRing(DPoint *);
   int InSameRing(DPoint *, DPoint *, DPoint *);
   void PrintSSSR();
-  void FindAromatic(QList<Bond>);
-  void BuildSSSR(QList<DPoint>);
-  void Add(QList<DPoint> *);
-  int CommonPoints(QList<DPoint> *, QList<DPoint> *);
-  bool CheckRing(QList<DPoint> *);
-  QList<DPoint> * GetRing(DPoint *);
+  void FindAromatic(QPtrList<Bond>);
+  void BuildSSSR(QPtrList<DPoint>);
+  void Add(QPtrList<DPoint> *);
+  int CommonPoints(QPtrList<DPoint> *, QPtrList<DPoint> *);
+  bool CheckRing(QPtrList<DPoint> *);
+  QPtrList<DPoint> * GetRing(DPoint *);
   void ClearPaths(void);
 };
 
