@@ -1,7 +1,7 @@
 // molecule_tools_2.cpp - Molecule's implementation of (more) functions
 
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qmessagebox.h>
 #include <iostream>
@@ -53,8 +53,8 @@ void Molecule::Scale(double bond_length) {
   }
 }
 
-QList<DPoint> Molecule::BreakRingBonds(DPoint *target1) {
-  QList<DPoint> bb;
+QPtrList<DPoint> Molecule::BreakRingBonds(DPoint *target1) {
+  QPtrList<DPoint> bb;
 
   for (tmp_bond = bonds.first(); tmp_bond != 0; tmp_bond = bonds.next() ) {
     if (tmp_bond->Find(target1) == true) {
@@ -112,6 +112,26 @@ DPoint *Molecule::GetAttachPoint(QString sf) {
     cout << tmp_pt->element << endl;
     return tmp_pt;
   }
+  if ( (sf.contains("biotin") > 0) ) {
+    up = AllPoints();
+    for (tmp_pt = up.first(); tmp_pt != 0; tmp_pt = up.next() ) {
+      if (tmp_pt->element == "OH") { 
+	cout << "Biotin-Point:OH" << endl; 
+	tmp_pt->element = "C";
+	break;
+      }
+    }
+    for (tmp_text = labels.first(); tmp_text != 0; tmp_text = labels.next()){
+      if (tmp_text->Start() == tmp_pt) {
+	cout << "removed" << endl;
+	labels.remove(tmp_text);
+	break;
+      }
+    }
+    cout << tmp_pt->element << endl;
+    return tmp_pt;
+  }
+  // end biotin
 
   // for amino acids
   double ymax = 0.0;
@@ -191,7 +211,7 @@ void Molecule::setGroupType(int g1) {
 // build DPoint::neighbors list(s)
 void Molecule::AllNeighbors() {
   int n1, n2, n3;
-  QList<DPoint> groupAtoms = AllPoints();
+  QPtrList<DPoint> groupAtoms = AllPoints();
 
   for (tmp_pt = groupAtoms.first(); tmp_pt != 0; tmp_pt = groupAtoms.next() ) {
     n1 = 0; n2 = 0; n3 = 0;
@@ -235,7 +255,7 @@ double Molecule::CalcPartialCharge(QString atomtype) {
 }
 
 Text *Molecule::CalcEmpiricalFormula(bool from_mw) {
-  QList<DPoint> up;
+  QPtrList<DPoint> up;
   QString ef;
   QStringList allatoms, oddatoms;
 
@@ -520,6 +540,7 @@ void Molecule::AddPeak(double d1, QString s1, QString s2) {
       tpeak->intensity += 1;
       delete tmp_peak;
       tmp_peak = 0;
+      break;
     }
   }
   if (tmp_peak != 0) peaklist.append(tmp_peak);
@@ -648,7 +669,7 @@ void Molecule::Reactivity(int react_type) {
   QString localatomtype;
   double sumcharge = 0.0;
   atomRxns.clear(); bondRxns.clear();
-  QListIterator<DPoint> atomrxniter(up);
+  QPtrListIterator<DPoint> atomrxniter(up);
   for ( ; atomrxniter.current(); ++atomrxniter ) {
     localatomtype = RetroAtomName( atomrxniter.current() );
     atomRxns.append(localatomtype);
@@ -659,7 +680,7 @@ void Molecule::Reactivity(int react_type) {
   }
   std::cout << "Calc total charge: " << sumcharge << std::endl;
   std::cout << "Atom count: " << atomRxns.count() << std::endl;
-  QListIterator<Bond> bondrxniter(bonds);
+  QPtrListIterator<Bond> bondrxniter(bonds);
   for ( ; bondrxniter.current(); ++bondrxniter ) {
     if (bondrxniter.current()->isCHBond() == false) {
       bondRxns.append(RetroBondName( bondrxniter.current() ));
