@@ -34,24 +34,39 @@ public:
       cas_label->setText(tr("CAS:") + s1);
     } 
   }
+  void setPCC(QString s1) { 
+    if (s1 != "unknown") {
+      pcc = s1;
+      getpcc->setEnabled(true);
+      pc_label->setText(tr("PubChem compound:") + s1);
+    } 
+  }
   void setName(QString s1) { 
     std::cout << s1 << std:: endl;
     if (s1 != "unknown") {
       name_label->setText(tr("Name:") + s1);
     } 
   }
+  void setSynonyms(QString s1) { 
+    std::cout << s1 << std:: endl;
+    if (s1 != "unknown") {
+      syn_label->setText(tr("Other names:") + s1);
+    } 
+  }
 
   public slots:
     void SendHelp();
   void doAccept();
+  void doPubChem();
 
  signals:
   void MIDClose();
 
  private:
   QCheckBox *mw_check, *ef_check, *dg_check, *ea_check;
-  QLabel *name_label, *cas_label;
-  QString mw, ea, ef, dg, casno;
+  QLabel *name_label, *cas_label, *syn_label, *pc_label;
+  QString mw, ea, ef, dg, casno, pcc;
+  QPushButton *getpcc;
 };
 
 #endif
