@@ -20,14 +20,16 @@ public:
   bool getNameCAS(QString, QString);
   bool get3DMol(QString);
   bool runBuild3D(QString);
+  bool runInChI(QString);
   bool status;
-  QString htfile, sname, scas, s3dmol;
+  QString htfile, spccompound, sname, scas, siupacname, s3dmol, fullinchi, 
+    shortinchi;
   QUrlOperator *op;
   QHttp hp1;
   QNetworkOperation *op1;
 
-  public slots:
-    void slotData(const QByteArray &);
+public slots:
+  void slotData(const QByteArray &);
   void slotFinished(QNetworkOperation *);
   void rf(bool);
 };
