@@ -41,14 +41,15 @@ NetChooseDialog::NetChooseDialog(QWidget *parent, QString name,QStringList r1):
 
   lv = new QListView(this);
   lv->addColumn("CAS");
-  lv->addColumn("Name");
+  lv->addColumn("IUPAC Name");
   lv->addColumn("Formula");
+  lv->addColumn("Other names");
   lv->addColumn("SMILES");
   lv->setSorting(0);
   mygrid->addMultiCellWidget(lv, 1, 1, 0, 4);
 
   int i1;
-  QString tmp_str, tcas, tformula, tformat, tname;
+  QString tmp_str, tcas, tformula, tformat, tname, taltname;
   QListViewItem *lvi;
 
   for (QStringList::Iterator ir = r1.begin(); 
@@ -59,24 +60,32 @@ NetChooseDialog::NetChooseDialog(QWidget *parent, QString name,QStringList r1):
     tcas = tmp_str.mid(1, i1-1);
     tmp_str.remove(0, i1 + 1);
     i1 = tmp_str.find("~");
-    tformula = tmp_str.mid(0, i1);
-    tmp_str.remove(0, i1 + 1);
-    i1 = tmp_str.find("~");
-    tformat = tmp_str.mid(0, i1);
+    tcas = tmp_str.mid(0, i1);
     tmp_str.remove(0, i1 + 1);
     i1 = tmp_str.find("~");
     tname = tmp_str.mid(0, i1);
     tmp_str.remove(0, i1 + 1);
+    i1 = tmp_str.find("~");
+    tformula = tmp_str.mid(0, i1);
+    tmp_str.remove(0, i1 + 1);
+    i1 = tmp_str.find("~");
+    taltname = tmp_str.mid(0, i1);
+    tmp_str.remove(0, i1 + 1);
+    i1 = tmp_str.find("~");
+    tformat = tmp_str.mid(0, i1);
+    tmp_str.remove(0, i1 + 1);
     //std::cout << tcas << "," << tname <<","<< tformula << "," << std::endl;
     tname.replace("\"", "");
     tcas.replace("\"", "");
     tformat.replace("\"", "");
+    taltname.replace("\"", "");
     tformula.replace("\"", "");
     lvi = new QListViewItem(lv);
     lvi->setText(0, tcas);
     lvi->setText(1, tname);
     lvi->setText(2, tformula);
-    lvi->setText(3, tformat);
+    lvi->setText(3, taltname);
+    lvi->setText(4, tformat);
     //lv->insertItem(lvi);
   }
 
@@ -93,7 +102,7 @@ NetChooseDialog::NetChooseDialog(QWidget *parent, QString name,QStringList r1):
 
 void NetChooseDialog::OK() {
   // save SMILES string of selected item
-  fn = lv->selectedItem()->text(3);
+  fn = lv->selectedItem()->text(4);
   fn.replace("\"", "");  // strip quotes
   accept();
 }
