@@ -4,7 +4,7 @@
 #define NEWGRAPHWIDGET_H
 
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qprinter.h>
@@ -36,7 +36,7 @@ class NewGraphWidget : public QWidget {
  private:
   int datatype;
   int output;
-  QList<GraphData> peaks;
+  QPtrList<GraphData> peaks;
   GraphData *tmp_data;
   QPixmap p1;
   QPrinter *printer;
