@@ -39,6 +39,7 @@ class Preferences {
     zoom = 100;
     mainFont = QFont("Helvetica", 10);
     rulerFont = QFont("Courier", 8);
+    bondcenter = false;
   }
   void setFile(QString fn, bool fb) {
     fileName = fn;
@@ -242,6 +243,8 @@ class Preferences {
     }
   }
   QString getCustomRingDir() { return customRingDir; }
+  void setBondCenter(bool bc1) { bondcenter = bc1; }
+  bool getBondCenter() { return bondcenter; }
 
  private:
   bool fixed_arrow, fixed_bond, fix_hydrogens;
@@ -263,6 +266,7 @@ class Preferences {
   int gridmode, gridspace, drawgrid, snapgrid;
   int zoom;  // not saved.
   QFont mainFont, rulerFont;  // added at user request
+  bool bondcenter;
 };
 
 #endif
