@@ -74,6 +74,11 @@ Render2D::Render2D(QWidget *parent, const char *name)
   rc.setMask(rc.createHeuristicMask());
   rotatecursor = QCursor(rc, 1, 1);
 
+  font_size_kludge = false;
+  hotkeymode = false;
+  hkprevmode = 0;
+  painter = new QPainter;
+
   // set printing defaults
   PrintSetup();  // see render2d_print.cpp
 }
@@ -214,6 +219,7 @@ void Render2D::setMode_DrawArrow(QString btype) {
   if (btype == "REGULAR") bracket_type = ARROW_REGULAR;
   if (btype == "TOP_HARPOON") bracket_type = ARROW_TOPHARPOON;
   if (btype == "BOTTOM_HARPOON") bracket_type = ARROW_BOTTOMHARPOON;
+  if (btype == "MIDDLE") bracket_type = ARROW_MIDDLE;
   if (btype == "DIDNT_WORK") bracket_type = ARROW_DIDNT_WORK;
   if (btype == "DASH") bracket_type = ARROW_DASH;
   if (btype == "BI1") bracket_type = ARROW_BI1;
@@ -436,6 +442,8 @@ void Render2D::Cut() {
   c->StartUndo(0, 0);
   c->Cut();
   mode = MODE_SELECT;  // the selection is gone, don't draw selection box
+  // the selection is gone, don't reference it anymore
+  highlightpoint = 0; highlightobject = 0;
   repaint(false);
 }
 
