@@ -94,11 +94,12 @@ class Render2D : public QWidget {
     void drawDownLine(QPoint, QPoint, QColor);
     void drawWavyLine(QPoint, QPoint, QColor);
     void drawArrow(QPoint, QPoint, QColor, int, int);
-    void drawBracket(QPoint, QPoint, QColor, int);
+    void drawBracket(QPoint, QPoint, QColor, int, QColor);
     void drawBox(QPoint, QPoint, QColor);
     void drawFillBox(QPoint, QPoint, QColor);
     void drawFillBox(QPoint, QPoint, QColor, bool, QColor, int);
     void drawCircle(QPoint, int, QColor);
+    void drawEllipse(QPoint, QPoint, bool, QColor, bool, QColor);
     void drawText(QChar, QPoint, QColor, QFont);
     void drawString(QString, QPoint, QColor, QFont);
     void drawTextReverse(QChar, QPoint, QColor, QFont);
@@ -145,6 +146,9 @@ class Render2D : public QWidget {
     void molCopy();
     void bondEdit();
     void bondInfo();
+    void textShape();
+    void bracketFill();
+    void bracketFillOff();
 
     // defined here:
     void setDirectDraw(bool dd1) { directdraw = dd1; }
@@ -186,6 +190,7 @@ class Render2D : public QWidget {
     QColor getBGColor() { return bgcolor; }
     void setWaitCursor() { setCursor(waitCursor); }
     void setArrowCursor() { setCursor(arrowCursor); }
+    bool getFontKludge() { return font_size_kludge; }
 
  signals:
     void SignalSetStatusBar(QString);
@@ -264,9 +269,10 @@ class Render2D : public QWidget {
   QTextStream output_ts;
   // SVG position correction
   int svg_dx, svg_dy;
-  // Output printer
-  QList<Paintable> paintqueue;
+  // Output printer and related classes
+  QPtrList<Paintable> paintqueue;
   QPrinter *printer;
+  QPainter *painter;
   // Text object, temp string to use when creating/editing text
   Text *localtext;
   QTextEdit *localtexteditor;
@@ -297,6 +303,13 @@ class Render2D : public QWidget {
   Molecule *targetmol;
   // current/temporary Molecule
   Molecule *tmp_molecule;
+  // kludge for PNG/BMP generation
+  bool font_size_kludge;
+  // track last known pointer position
+  QPoint lastmouse;
+  // remember mode if using "hot key"
+  bool hotkeymode;
+  int hkprevmode;
 };
 
 #endif
