@@ -74,6 +74,7 @@ void Render2D::drawLine(QPoint a, QPoint b, int t, QColor c1, int s) {
     output_ts << c1.name() << "\" stroke-width=\"" << t << "\"/>" << endl;
     return;
   }
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put line on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -89,18 +90,20 @@ void Render2D::drawLine(QPoint a, QPoint b, int t, QColor c1, int s) {
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
-  p.scale(zoomFactor, zoomFactor);
+  */
+  //p.scale(zoomFactor, zoomFactor);
   if (s == 0) // solid
-    //p.setPen(QPen(c1, t - 1));
-    p.setPen(QPen(c1, t));
+    //p.setPen(QPen(c1, t));
+    painter->setPen(QPen(c1, t));
   else // dashed -- always apply thickness
-    p.setPen(QPen(c1, t, DotLine));
-  p.drawLine(a, b);
+    //p.setPen(QPen(c1, t, DotLine));
+    painter->setPen(QPen(c1, t, DotLine));
+  //p.drawLine(a, b);
+  painter->drawLine(a, b);
 }
 
 // This function exists to turn Polyline into bits for drawLine(...)
@@ -114,22 +117,23 @@ void Render2D::drawPolyline(QPointArray a1, QColor c1) {
 // note that this only works on screen and bitmap (for now)
 void Render2D::drawBezier(QPointArray a1, QColor c1, bool drawPoints,
 			  int arrowHead) {
-  QPainter p;
+  /*
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
+  */
+  painter->setPen(c1);
   int xp1, yp1;
   if (drawPoints) {
     for (int l1 = 0; l1 <= bezier_count; l1++) {
       a1.point(l1, &xp1, &yp1);
-      p.drawRect(xp1 - 1, yp1 - 1, 3, 3);
+      painter->drawRect(xp1 - 1, yp1 - 1, 3, 3);
     }
   }
   if (drawPoints == false) { 
-    p.drawCubicBezier(a1); 
+    painter->drawCubicBezier(a1); 
     QPoint ar1, ar2; // apparent arrowhead shaft:  (ar1)-->(ar2)
     ar1 = a1.point( a1.count() - 2 );
     ar2 = a1.point( a1.count() - 1 );
@@ -156,10 +160,11 @@ void Render2D::drawBezier(QPointArray a1, QColor c1, bool drawPoints,
     return; 
   }
   if ( (mode == MODE_DRAWBEZIER) && (bezier_count < 3) ) return;
-  p.drawCubicBezier(a1);
+  painter->drawCubicBezier(a1);
 }
 
-void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type) {
+void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type, 
+			   QColor fillColor) {
   int tl_x, tl_y, br_x, br_y, swp;
   tl_x = a.x();
   tl_y = a.y();
@@ -174,15 +179,29 @@ void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type) {
   QPoint tr(br_x, tl_y);
   QPoint br(br_x, br_y);
   if ( (type == BRACKET_BOX) || (type == BRACKET_CLOSEDSQUARE)) {
+    /*
     drawLine(tl, bl, 1, c1);
     drawLine(bl, br, 1, c1);
     drawLine(tr, br, 1, c1);
     drawLine(tl, tr, 1, c1);
+    */
+    if (fillColor.isValid() == true) {
+      drawFillBox(tl, br, fillColor, true, c1, 0);
+    } else {
+      drawBox(tl, br, c1);
+    }
   }
   if ( (type == BRACKET_ELLIPSE) || (type == BRACKET_CIRCLE)) {
+    /*
     QPointArray el;
     el.makeEllipse(tl.x(), tl.y(), br.x() - tl.x(), br.y() - tl.y() );
     drawPolyline(el, c1);
+    */
+    if (fillColor.isValid() == true) {
+      drawEllipse(tl, br, true, c1, true, fillColor);
+    } else {
+      drawEllipse(tl, br, true, c1, false, fillColor);
+    }
   }
   if (type == BRACKET_SQUARE) {
     drawLine(tl, bl, 1, c1);
@@ -233,7 +252,6 @@ void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type) {
 
 void Render2D::drawWavyLine(QPoint a, QPoint b, QColor c1) {
   /*
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
@@ -316,6 +334,7 @@ void Render2D::drawUpLine(QPoint a, QPoint b, QColor c1) {
     output_ts << a.x() << "," << a.y() << "\"/>" << endl;
     return;
   }
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put line on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -327,19 +346,20 @@ void Render2D::drawUpLine(QPoint a, QPoint b, QColor c1) {
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
-  p.setBrush(QBrush(c1));
+  */
+  painter->setPen(c1);
+  painter->setBrush(QBrush(c1));
   QPointArray triangle(3);
   triangle.setPoint(0, t1);
   triangle.setPoint(1, t2);
   triangle.setPoint(2, a);
-  p.drawPolygon(triangle);
+  painter->drawPolygon(triangle);
+  painter->setBrush( QBrush(Qt::NoBrush) );
 }
 
 void Render2D::drawDownLine(QPoint a, QPoint b, QColor c1) {
@@ -416,6 +436,28 @@ void Render2D::drawArrow(QPoint a, QPoint b, QColor c1, int s1, int th1) {
     else
       drawLine(b, a2, th1, c1);
   }
+  if (s1 == ARROW_MIDDLE) {
+    QPoint m1 = Midpoint(a,b);
+    double newang5 = ang + 45.0;
+    double newang6 = ang - 45.0;
+    double newang7 = oppang + 45.0;
+    double newang8 = oppang - 45.0;
+    QPoint a5( my_round(m1.x() + (cos(newang5/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang5/MOL_ARAD) * 10.0)) );
+    QPoint a6( my_round(m1.x() + (cos(newang6/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang6/MOL_ARAD) * 10.0)) );
+    QPoint a7( my_round(m1.x() + (cos(newang7/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang7/MOL_ARAD) * 10.0)) );
+    QPoint a8( my_round(m1.x() + (cos(newang8/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang8/MOL_ARAD) * 10.0)) );
+    drawLine(a, b, th1, c1);
+    //drawLine(b, a1, th1, c1);
+    //drawLine(b, a2, th1, c1);
+    drawLine(m1, a5, th1, c1);
+    drawLine(m1, a6, th1, c1);
+    //drawLine(m1, a7, th1, c1);
+    //drawLine(m1, a8, th1, c1);
+  }
   if (s1 == ARROW_DIDNT_WORK) {
     QPoint m1 = Midpoint(a,b);
     double newang5 = ang + 45.0;
@@ -508,14 +550,16 @@ void Render2D::drawArrow(QPoint a, QPoint b, QColor c1, int s1, int th1) {
 }
 
 void Render2D::drawBox(QPoint a, QPoint b, QColor c1) {
-  QPainter p;
+  /*
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
-  p.drawRect(QRect(a, b));
+  */
+  painter->setPen(c1);
+  painter->setBrush( QBrush(Qt::NoBrush) );
+  painter->drawRect(QRect(a, b));
 }
 
 void Render2D::drawFillBox(QPoint a, QPoint b, QColor c1) {
@@ -549,6 +593,7 @@ void Render2D::drawFillBox(QPoint a, QPoint b, QColor c1, bool border,
 	      << "\" fill=\"" << c1.name() << "\"/>" << endl; 
     return;
   }
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put line on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -559,31 +604,51 @@ void Render2D::drawFillBox(QPoint a, QPoint b, QColor c1, bool border,
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
-  p.fillRect(QRect(a, b), c1);
+  */
+  painter->setPen(c1);
+  painter->fillRect(QRect(a, b), c1);
   if (border) {
-    if (style == 0) p.setPen(bordercolor);
-    if (style == 1) p.setPen(QPen(bordercolor,0,DotLine));
-    p.drawRect(QRect(a,b));
+    if (style == 0) painter->setPen(bordercolor);
+    if (style == 1) painter->setPen(QPen(bordercolor,0,DotLine));
+    painter->drawRect(QRect(a,b));
   }
 }
 
 void Render2D::drawCircle(QPoint a, int rad, QColor cfill) {
-  QPainter p;
+  /*
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setBrush(cfill);
-  p.setPen(QColor(0,0,0));
-  p.drawEllipse(a.x(), a.y(), rad * 2, rad * 2);
+  */
+  painter->setBrush(cfill);
+  painter->setPen(QColor(0,0,0));
+  painter->drawEllipse(a.x(), a.y(), rad * 2, rad * 2);
+  painter->setBrush( QBrush(Qt::NoBrush) );
+}
+
+void Render2D::drawEllipse(QPoint tl, QPoint br, bool drawLine,
+			   QColor lineColor, bool drawFill, QColor fillColor)
+{
+  /*
+  if (directdraw) 
+    p.begin(this);
+  else
+    p.begin(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
+  */
+  if (drawFill)
+    painter->setBrush(fillColor);
+  if (drawLine)
+    painter->setPen(lineColor);
+  painter->drawEllipse( QRect(tl, br) );
+  painter->setBrush( QBrush(Qt::NoBrush) );
 }
 
 void Render2D::drawText(QChar ch, QPoint a, QColor c1, QFont f) {
@@ -629,6 +694,7 @@ void Render2D::drawText(QChar ch, QPoint a, QColor c1, QFont f) {
     output_ts << ch << "</text>" << endl;
     return;
   }
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put line on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -640,15 +706,15 @@ void Render2D::drawText(QChar ch, QPoint a, QColor c1, QFont f) {
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
-  p.setFont(f);
-  p.drawText(a, ch);
+  */
+  painter->setPen(c1);
+  painter->setFont(f);
+  painter->drawText(a, ch);
 }
 
 void Render2D::drawString(QString s1, QPoint a, QColor c1, QFont f) {
@@ -672,6 +738,7 @@ void Render2D::drawString(QString s1, QPoint a, QColor c1, QFont f) {
     output_ts << s1 << "</text>" << endl;
     return;
   }
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put line on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -683,33 +750,34 @@ void Render2D::drawString(QString s1, QPoint a, QColor c1, QFont f) {
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
-  p.setFont(f);
-  p.drawText(a, s1);
+  */
+  painter->setPen(c1);
+  painter->setFont(f);
+  painter->drawText(a, s1);
 }
 
 void Render2D::drawTextReverse(QChar ch, QPoint a, QColor c1, QFont f) {
-  QPainter p;
+  /*
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
-  p.setFont(f);
-  QFontMetrics fm = p.fontMetrics();
+  */
+  painter->setPen(c1);
+  painter->setFont(f);
+  QFontMetrics fm = painter->fontMetrics();
   QPoint topleft(a.x(), a.y() - fm.ascent());
   QPoint bottomright(a.x() + fm.width(ch), a.y() + fm.descent());
   QRect fr(topleft, bottomright);
-  p.fillRect(fr, c1);
-  p.setPen(bgcolor);
-  p.drawText(a, ch);
+  painter->fillRect(fr, c1);
+  painter->setPen(bgcolor);
+  painter->drawText(a, ch);
 }
 
 void Render2D::drawPixmap(QPoint a, QPixmap pix) {
@@ -741,6 +809,7 @@ void Render2D::drawPixmap(QPoint a, QPixmap pix) {
     output_ts << "end" << endl << "grestore" << endl << endl;
     return;
   }
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put line on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -750,16 +819,17 @@ void Render2D::drawPixmap(QPoint a, QPixmap pix) {
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.drawPixmap(a, pix);
+  */
+  painter->drawPixmap(a, pix);
 }
 
 void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
+  /*
   if (outputDevice == OUTPUT_PRINTER) {
     // put curve on paintqueue to render in Print()
     Paintable *pa = new Paintable;
@@ -781,13 +851,13 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     paintqueue.append(pa);
     return;
   }
-  QPainter p;
   if (directdraw) 
     p.begin(this);
   else
     p.begin(&dbuffer);
   p.scale(zoomFactor, zoomFactor);
-  p.setPen(c1);
+  */
+  painter->setPen(c1);
   if (wh == "CW180") {
     // calculate curve
     QPoint ce = Midpoint(a, b);
@@ -966,9 +1036,19 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
 // just the drawing if page_size set to paper (LETTER, LEGAL, A4, ...)
 // whole area if set to a screen size (640, 800, 1024)
 QPixmap Render2D::MakePixmap(bool transp) {
+  double oldspace = preferences.getDoubleBondOffset();
+  preferences.setDoubleBondOffset( oldspace * 2.0 );
+  font_size_kludge = true;
   prev_mode = mode;
   QRect r;
   c->SelectAll();
+
+  DPoint dp1;
+  selectionBox = c->selectionBox();
+  QRect finalsize = selectionBox;
+  dp1.set( selectionBox.topLeft() );
+  c->Resize(&dp1, 2.0);
+
   if (preferences.getPageSize() < PAGE_640)
     r = c->selectionBox();
   else
@@ -988,6 +1068,12 @@ QPixmap Render2D::MakePixmap(bool transp) {
   bitBlt( &pm, 0, 0, &dbuffer, r.left(), r.top(), r.width(), r.height() );
   //bitBlt( &pm, 0, 0, this, r.left(), r.top(), r.width(), r.height() );
 
+  QImage final1;
+  final1 = pm;
+  final1 = final1.smoothScale( finalsize.width(), finalsize.height(),
+			       QImage::ScaleMin );
+  pm = final1;
+
   if (transp) {
     QBitmap bm(r.size());
     bm = pm;
@@ -999,6 +1085,15 @@ QPixmap Render2D::MakePixmap(bool transp) {
   }
 
   mode = prev_mode;
+
+  c->SelectAll();
+  selectionBox = c->selectionBox();
+  dp1.set( selectionBox.topLeft() );
+  c->Resize(&dp1, 0.5);
+  c->DeselectAll();
+  font_size_kludge = false;
+  preferences.setDoubleBondOffset( oldspace );
+
   return pm;
 }
 
