@@ -6,6 +6,7 @@
 #include <qglobal.h>
 #include <qcursor.h>
 #include <qmessagebox.h>
+#include <qcolordialog.h>
 
 using std::cout;
 using std::endl;
@@ -15,9 +16,11 @@ using std::endl;
 #include "drawable.h"
 #include "molecule.h"
 #include "text.h"
+#include "bracket.h"
 #include "defs.h"
 #include "xdc_event.h"
 #include "molinfodialog.h"
+#include "textshapedialog.h"
 
 // move point to grid if needed
 QPoint Render2D::GridLock(QPoint qp1) {
@@ -38,11 +41,13 @@ QPoint Render2D::GridLock(QPoint qp1) {
     
     repaint(false);
     directdraw = true;
+    painter->begin(this);
     drawBox(QPoint( qp1.x() - 2, 
 		    qp1.y() - 2 ),
 	    QPoint( qp1.x() + 2, 
 		    qp1.y() + 2 ),
 	    QColor(255,0,0));
+    painter->end();
     directdraw = false;
     
     return qp1;
@@ -144,6 +149,50 @@ void Render2D::bondInfo() {
 
   QMessageBox::information( 0, tr("Object information"), objinf);
 }
+void Render2D::textShape() {
+  localtext = (Text *)highlightobject;
+  TextShapeDialog *tsd = 
+    new TextShapeDialog(this, "text shape dialog");
+
+  tsd->set_stype( localtext->getShape() );
+  tsd->setBorderCheck( localtext->getBorder() );
+  tsd->setFillCheck( localtext->getFill() );
+  tsd->setBorderColor( localtext->getBorderColor() );
+  tsd->setFillColor( localtext->getFillColor() );
+  tsd->setWidth( localtext->getShapeWidth() );
+  tsd->setHeight( localtext->getShapeHeight() );
+
+  if ( tsd->exec() ) {
+    std::cout << "textShape OK" << std::endl;
+  }
+
+  localtext->setShape( tsd->get_stype() );
+  localtext->setBorder( tsd->getBorderCheck() );
+  localtext->setFill( tsd->getFillCheck() );
+  localtext->setBorderColor( tsd->getBorderColor() );
+  localtext->setFillColor( tsd->getFillColor() );
+  localtext->setShapeWidth( tsd->getWidth() );
+  localtext->setShapeHeight( tsd->getHeight() );
+
+  delete tsd;
+
+  localtext = 0;
+}
+void Render2D::bracketFill() {
+  Bracket *lbracket = (Bracket *)highlightobject;
+  QColor b1color = lbracket->getFillColor();
+
+  b1color = QColorDialog::getColor(b1color);
+
+  if (b1color.isValid() == true) {
+    lbracket->setFill(true);
+    lbracket->setFillColor(b1color);
+  }
+}
+void Render2D::bracketFillOff() {
+  Bracket *lbracket = (Bracket *)highlightobject;
+  lbracket->setFill(false);
+}
 
 void Render2D::mousePressEvent(QMouseEvent *e1) {
   if (localstring == "XDC_DELETE_ME") {
@@ -176,12 +225,27 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
   }
   //cout << "start at " << curqpt.x() << "," << curqpt.y() << endl;
 
-  if ( ( (mode == MODE_SELECT) || (mode == MODE_SELECT_MOVE_OBJECT) ) 
-       && mouse3down ) {
+  // can the current mode use right button popup menu?
+  bool rbm = false;
+  if (mode == MODE_SELECT) rbm = true;
+  if (mode == MODE_SELECT_MOVE_OBJECT) rbm = true;
+  if (mode == MODE_DRAWBRACKET) rbm = true;
+
+  if ( rbm && mouse3down ) {
     //if (rtclickpopup != 0) delete rtclickpopup;
     rtclickpopup = new QPopupMenu(this);
     int id1;
     bool menu_ok = false;
+    if ( (mode == MODE_DRAWBRACKET) && (highlightobject == 0) ) {
+      // put nearest bracket into highlightobject
+      DPoint *e = new DPoint;
+      e->x = curqpt.x(); e->y = curqpt.y();
+      double distobj;
+      // get Drawable of nearest object
+      Drawable *no = c->FindNearestObject(e, distobj);
+      if ( (distobj < 5.0) && (no->Type() == TYPE_BRACKET) )
+	highlightobject = no;
+    }
     if (highlightobject != 0) {
       QString rtmt;
       rtmt = tr("Object");
@@ -202,6 +266,12 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
       rtclickpopup->insertItem( tr("Edit"), this, SLOT(bondEdit()) ); 
       if (highlightobject->Type() == TYPE_BOND)
 	rtclickpopup->insertItem( tr("Info"), this, SLOT(bondInfo()) ); 
+      if (highlightobject->Type() == TYPE_BRACKET) {
+	rtclickpopup->insertItem( tr("Fill color..."), this, SLOT(bracketFill()) ); 
+	rtclickpopup->insertItem( tr("No fill"), this, SLOT(bracketFillOff()) ); 
+      }
+      if (highlightobject->Type() == TYPE_TEXT)
+	rtclickpopup->insertItem( tr("Shape..."), this, SLOT(textShape()) ); 
       menu_ok = true;
     }
     targetmol = c->insideMolecule(tmp_pt2);
@@ -219,11 +289,35 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
       rtclickpopup->popup( mapToGlobal(e1->pos()) );
   }
 
-    // MODE_TEXT: call special function to handle text events
-    if (mode == MODE_TEXT) {
-        DrawText_mousePressEvent(e1, curqpt);
-        return;
+  // MODE_TEXT with right button
+  if ( (mode == MODE_TEXT) && mouse3down ) {
+    rtclickpopup = new QPopupMenu(this);
+    int id1;
+    bool menu_ok = false;
+    if (highlightobject != 0) {
+      QString rtmt;
+      rtmt = tr("Object");
+      if (highlightobject->Type() == TYPE_TEXT)
+	rtmt = tr("Text");
+      id1 = rtclickpopup->insertItem( rtmt ); 
+      rtclickpopup->setItemEnabled(id1, false);
+      rtclickpopup->insertItem( tr("Edit"), this, SLOT(bondEdit()) ); 
+      if (highlightobject->Type() == TYPE_TEXT)
+	rtclickpopup->insertItem( tr("Shape..."), this, SLOT(textShape()) ); 
+      menu_ok = true;
     }
+    mouse3down = false;
+    if (menu_ok) {
+      rtclickpopup->popup( mapToGlobal(e1->pos()) );
+      return;
+    }
+  }
+
+  // MODE_TEXT: call special function to handle text events
+  if (mode == MODE_TEXT) {
+    DrawText_mousePressEvent(e1, curqpt);
+    return;
+  }
 
     // MODE_SELECT_LASSO: start lasso
     if ( mode == MODE_SELECT_LASSO ) {
@@ -248,6 +342,10 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
 	    mode = MODE_DRAWLINE_DRAWING;
 	    savedBondOrder = highlightpoint->otherBond->Order();
 	    c->Erase(highlightpoint->otherBond);
+	    if (savedBondOrder == 2)
+	      c->Erase(highlightpoint->otherBond);
+	    if (savedBondOrder == 3)
+	      c->Erase(highlightpoint->otherBond);
 	    startpoint = highlightpoint->other;
 	    endpoint = 0;
 	    highlightpoint = 0;
@@ -563,6 +661,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     if (mode == MODE_DRAWBEZIER) {
       repaint(false);
       directdraw = true;
+      painter->begin(this);
       if (bezier_count < 3) {
 	tmp_bezier.setPoint(bezier_count, curqpt.x(), curqpt.y());
 	drawBezier(tmp_bezier, currentColor, true);
@@ -580,6 +679,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	bezier_count = 0;
       }
       directdraw = false;
+      painter->end();
       return;
     }
 
@@ -620,6 +720,9 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	selectOrigin.setY(selectPrev.y());
 	selectPrev.setY(tmp1);
       }
+      repaint(false);
+      directdraw = true;
+      painter->begin(this);
       drawBox(selectOrigin, selectPrev, QColor(255,255,255));
       bool shiftdown = false;
       if ((e1->state() & ShiftButton) == ShiftButton)
@@ -632,7 +735,9 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	mode = MODE_SELECT_MULTIPLE_SELECTED;
       else
 	mode = MODE_SELECT;
-      repaint(false);
+      directdraw = false;
+      painter->end();
+      return;
     }
 
     // MODE_SELECT_MOVE_MULTIPLE: finish moving
@@ -916,16 +1021,64 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 
     // MODE_SYMBOL: create Symbol
     if ( (mode == MODE_SYMBOL) && (!mouse1down) ) {
-        endpoint = new DPoint;
-        endpoint->set
-        (curqpt);
-        if (highlightpoint != 0) {
-            c->addSymbol(highlightpoint, symbolfile);  // add to existing point
-        } else {
-            c->addSymbol(endpoint, symbolfile);  // add at current mouse position
-        }
-        endpoint = NULL;
+      if (highlightpoint == 0) {
+	endpoint = new DPoint(curqpt);
+      } else {
+	endpoint = highlightpoint;
+      }
+      if (symbolfile == "antibody") {
+	c->DeselectAll();
+	DPoint *ab0, *ab1, *ab2;
+	double dab, dabscale;
+	dabscale = preferences.getBond_fixedlength();
+	dab = dabscale / 1.41421;
+	ab0 = new DPoint(endpoint);
+	ab0->y = ab0->y - dabscale;
+	ab1 = new DPoint(ab0);
+	ab2 = new DPoint(ab0);
+	ab1->x = ab1->x - dab;
+	ab1->y = ab1->y - dab;
+	ab2->x = ab2->x + dab;
+	ab2->y = ab2->y - dab;
+	preferences.setBondCenter(true);
+	evt = new XDC_Event(EVT_ADD_BOND);
+	evt->setStart(endpoint);
+	evt->setEnd(ab0);
+	evt->setParam1(2);
+	evt->setParam2(2);
+	evt->setColor(currentColor);
+	evt->setBool1(true);
+	emit XDCEventSignal(evt);
+	preferences.setBondCenter(false);
+	evt = new XDC_Event(EVT_ADD_BOND);
+	evt->setStart(ab0);
+	evt->setEnd(ab1);
+	evt->setParam1(1);
+	evt->setParam2(2);
+	evt->setColor(currentColor);
+	evt->setBool1(true);
+	emit XDCEventSignal(evt);
+	evt = new XDC_Event(EVT_ADD_BOND);
+	evt->setStart(ab0);
+	evt->setEnd(ab2);
+	evt->setParam1(1);
+	evt->setParam2(2);
+	evt->setBool1(true);
+	evt->setColor(currentColor);
+	emit XDCEventSignal(evt);
+	mode = MODE_SELECT_MULTIPLE_SELECTED;
+	selectionBox = c->selectionBox();
         repaint(false);
+	endpoint = 0;
+	return;
+      }
+      if (highlightpoint != 0) {
+	c->addSymbol(highlightpoint, symbolfile);  // add to existing point
+      } else {
+	c->addSymbol(endpoint, symbolfile);  // add at current mouse position
+      }
+      endpoint = NULL;
+      repaint(false);
     }
 
     // MODE_DRAWNEWMAN_*: create Newman projection
@@ -992,6 +1145,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
         endpoint = new DPoint;
         endpoint->set
         (curqpt);
+	c->setThickKludge(thick);
         // are we smart-placing this ring?
         if ( (smartplace != 0) && (highlightpoint != 0) ) {
 	  cout << "smart placement! Mode " << smartplace << endl;
@@ -1010,10 +1164,12 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	  selectionBox = c->selectionBox();
 	  repaint(false);
 	  smartplace = 0;
+	  c->setThickKludge(-1);
 	  return;
         }
         // translate ring to click point
         c->load(symbolfile);
+	c->setThickKludge(-1);
         mode = MODE_SELECT_MULTIPLE_SELECTED;
         emit SignalSetStatusBar( tr("Select mode: left click on object to move, right click on object to edit") );
         setCursor(sizeAllCursor);
@@ -1038,14 +1194,21 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     localstring = " ";
   }
 
+  if (mode == MODE_DRAWBRACKET) highlightobject = 0;
+
   if ( (mode == MODE_RING) && mouse1down )
     return;
 
+  if ( (mode == MODE_DRAWBEZIER) && mouse1down )
+    return;
+
   QPoint curqpt = zoomCorrectReverse( e1->pos() );
   if (preferences.getSnapGrid() != GRID_NONE) {
     curqpt = GridLock(curqpt);
   }
 
+  lastmouse = curqpt;
+
   moved = true;
 
   DPoint tmp_pt(curqpt.x(), curqpt.y()); 
@@ -1058,12 +1221,14 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     if (tmp_molecule != 0) {
       repaint(false);
       directdraw = true;
+      painter->begin(this);
       QRect mr = tmp_molecule->BoundingBoxAll();
       mr.setLeft(mr.left() - 2);
       mr.setRight(mr.right() + 2);
       mr.setTop(mr.top() - 2);
       mr.setBottom(mr.bottom() + 2);
       drawBox( mr.topLeft(), mr.bottomRight(), QColor(0,0,255) );
+      painter->end();
       directdraw = false;
     } else {
       repaint(false);
@@ -1407,9 +1572,11 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     sang.setNum(ang);
     slen.setNum(len);
     emit SignalSetStatusBar( tr("Draw Line - Length = ") + slen + tr(", Angle = ") + sang);
+    painter->begin(this);
     drawLine( startpoint->toQPoint(), endpoint->toQPoint(), thick,
 	      currentColor );
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1441,6 +1608,7 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     QPoint spoint, epoint, ipoint1, ipoint2;
     spoint = startpoint->toQPoint();
     ipoint1 = spoint;
+    painter->begin(this);
     for (n1 = 0; n1 < nseg; n1++) {
       ipoint2.setX( my_round(ipoint1.x() + cos(alt_ang1) * blen) );
       ipoint2.setY( my_round(ipoint1.y() + sin(alt_ang1) * blen) );
@@ -1449,6 +1617,7 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
       ipoint1 = ipoint2;
     }
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1473,9 +1642,11 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	}
       }
     }
+    painter->begin(this);
     drawLine( startpoint->toQPoint(), endpoint->toQPoint(), 1,
 	      currentColor, 1 );
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1500,8 +1671,10 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	}
       }
     }
+    painter->begin(this);
     drawUpLine( startpoint->toQPoint(), endpoint->toQPoint(), currentColor );
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1526,8 +1699,10 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	}
       }
     }
+    painter->begin(this);
     drawDownLine(startpoint->toQPoint(), endpoint->toQPoint(), currentColor);
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1552,8 +1727,10 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	}
       }
     }
+    painter->begin(this);
     drawWavyLine(startpoint->toQPoint(), endpoint->toQPoint(), currentColor);
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1565,9 +1742,11 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     if (preferences.getArrow_fixed()) { // fix endpoint if fixed set
       CorrectEndpoint_arrow();
     }
+    painter->begin(this);
     drawArrow( startpoint->toQPoint(), endpoint->toQPoint(), currentColor,
 	       bracket_type, thick );
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1580,9 +1759,11 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     //if (fixed) { // fix endpoint if fixed set
     //  CorrectEndpoint();
     //}
+    painter->begin(this);
     drawCurveArrow( startpoint->toQPoint(), endpoint->toQPoint(),
 		    currentColor, symbolfile );
     directdraw = false;
+    painter->end();
     return;
   }
 
@@ -1609,11 +1790,17 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
       bdy = endpoint->y - startpoint->y;
       std::cout << "after:" << bdx << "," << bdy << std::endl;
     }
+    QColor icv;
+    painter->begin(this);
     drawBracket( startpoint->toQPoint(), endpoint->toQPoint(), currentColor,
-		 bracket_type );
+		 bracket_type, icv );
     directdraw = false;
+    painter->end();
     return;
   }
+
+  // just in case
+  directdraw = false;
 }
 
 // handle resize event
@@ -1629,25 +1816,35 @@ void Render2D::paintEvent(QPaintEvent *) {
   }
   // draw background
   //drawFillBox(QPoint(0,0), QPoint(renderWidth, renderHeight), bgcolor);
+
+  // initialize global painter object
+  if (outputDevice == OUTPUT_PRINTER) {
+    std::cout << "printer" << std::endl;
+    painter->begin(printer);
+  }
+  if (outputDevice == OUTPUT_SCREEN) {
+    std::cout << "screen" << std::endl;
+    if (directdraw) 
+      painter->begin(this);
+    else
+      painter->begin(&dbuffer);
+    painter->scale(zoomFactor, zoomFactor);
+  }
+
   // clear buffer pixmap
   dbuffer.fill(bgcolor);
   // draw grid as needed
   int i1, cl1;
   if (preferences.getDrawGrid() == GRID_SQUARE) {
     i1 = my_round( (double)preferences.getGridSpacing() * zoomFactor );
-    QPainter p;
-    if (directdraw) 
-      p.begin(this);
-    else
-      p.begin(&dbuffer);
-    p.setPen( QPen(QColor(128,128,128), 1, Qt::DotLine) );
+    painter->setPen( QPen(QColor(128,128,128), 1, Qt::DotLine) );
     // draw horizontal
     for (cl1 = i1; cl1 < renderHeight; cl1 += i1) {
-      p.drawLine(0,cl1,renderWidth,cl1);
+      painter->drawLine(0,cl1,renderWidth,cl1);
     }
     // draw vertical
     for (cl1 = i1; cl1 < renderWidth; cl1 += i1) {
-      p.drawLine(cl1,0,cl1,renderHeight);
+      painter->drawLine(cl1,0,cl1,renderHeight);
     }
   }
   if (preferences.getDrawGrid() == GRID_HEX) {
@@ -1657,12 +1854,7 @@ void Render2D::paintEvent(QPaintEvent *) {
     double hexgap = 2.0 * hexhoriz + (double)i1;
     double hexelevation = hexhoriz * 1.73205;
     double hex_initx, hex_rightx;
-    QPainter p;
-    if (directdraw) 
-      p.begin(this);
-    else
-      p.begin(&dbuffer);
-    p.setPen( QPen(QColor(128,128,128), 1, Qt::DotLine) );
+    painter->setPen( QPen(QColor(128,128,128), 1, Qt::DotLine) );
     for (double hex_y = 0.0; hex_y < renderHeight; hex_y += hexelevation) {
       if (hexoffset)
 	hex_initx = hexhoriz;
@@ -1670,10 +1862,11 @@ void Render2D::paintEvent(QPaintEvent *) {
 	hex_initx = hexgap;
       for (double hex_x = hex_initx; hex_x < renderWidth; hex_x += hexgap) {
 	hex_rightx = hex_x + (double)i1;
-	p.drawLine(hex_x,hex_y,hex_rightx,hex_y);
-	p.drawLine(hex_x, hex_y, hex_x - hexhoriz, hex_y + hexelevation);
-	p.drawLine(hex_rightx, hex_y, 
-		   hex_rightx + hexhoriz, hex_y + hexelevation);
+	painter->drawLine(hex_x,hex_y,hex_rightx,hex_y);
+	painter->drawLine(hex_x, hex_y, hex_x - hexhoriz, 
+			  hex_y + hexelevation);
+	painter->drawLine(hex_rightx, hex_y, 
+			  hex_rightx + hexhoriz, hex_y + hexelevation);
 	hex_x = hex_rightx;
       }
       hexoffset = !hexoffset;
@@ -1690,24 +1883,6 @@ void Render2D::paintEvent(QPaintEvent *) {
 	    QColor(0,0,0));
   }
 
-  /* OBSOLETE when using QTextEdit to edit text
-     if ( (mode == MODE_TEXT) && (localtext != 0) )
-     localtext->EditRender();
-  */
-
-  /*
-  // draw select circles
-  if (mode < 150) {
-  QList<DPoint> allpts = c->UniquePoints();
-  DPoint *tmp_pt;
-  for (tmp_pt = allpts.first(); tmp_pt != NULL; tmp_pt = allpts.next()) {
-  if (tmp_pt->isHighlighted() == true) {
-  drawCircle(tmp_pt->toQPoint() + QPoint(-2,-2), 4, QColor(255,0,0));
-  }
-  }
-  }
-  */
-
   // if multiple selection, draw rotate and resize handles
   if ( (mode > 120) && (mode < 129) ) {
     // draw selection box
@@ -1744,6 +1919,7 @@ void Render2D::paintEvent(QPaintEvent *) {
   // now bitBlt buffer onto widget
   bitBlt(this, 0, 0, &dbuffer);
   finishedPainting = true;
+  painter->end();
 }
 
 void Render2D::zoomEvent() {
