@@ -1,6 +1,6 @@
 #include <iostream>
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
 #include <qmessagebox.h>
 #include <qregexp.h>
@@ -137,7 +137,7 @@ QString Molecule::RetroBondName(Bond *lbond, bool runsssr) {
   // ...where canonicalization will be accomplished by alphabetizing
   // within each level.
 
-  QListIterator<Bond> innerIter1(bonds), innerIter2(bonds), innerIter3(bonds), 
+  QPtrListIterator<Bond> innerIter1(bonds), innerIter2(bonds), innerIter3(bonds), 
     outerIter(bonds);
   QStringList innerstrlist1, innerstrlist2, innerstrlist3;
   Bond *local_tmp_bond, *inner_tmp_bond;
@@ -205,7 +205,7 @@ QString Molecule::RetroBondName(Bond *lbond, bool runsssr) {
 
 QString Molecule::RetroTraverseBonds(DPoint *parentNode, DPoint *thisNode,
 				     Bond *this_bond, int tlevel) {
-  QListIterator<Bond> innerIter1(bonds), innerIter2(bonds), innerIter(bonds), 
+  QPtrListIterator<Bond> innerIter1(bonds), innerIter2(bonds), innerIter(bonds), 
     outerIter(bonds);
   QStringList innerstrlist1, innerstrlist2, innerstrlist3;
   Bond *local_tmp_bond, *inner_tmp_bond;
