@@ -2,7 +2,7 @@
 // License notice follows:
 /* JMDraw.java
  *
- * $RCSfile: sdg.h,v $    $Author: bherger $    $Date: 2004/01/24 17:15:50 $    $Revision: 1.1.1.1 $
+ * $RCSfile: sdg.h,v $    $Author: bherger $    $Date: 2005/05/18 01:06:37 $    $Revision: 1.2 $
  *
  * Copyright (C) 1997, 1998, 1999, 2000  The JChemPaint project
  * 
@@ -31,9 +31,9 @@
 #ifndef SDG_H
 #define SDG_H
 
-#include <qarray.h>
-#include <qvector.h>
-#include <qlist.h>
+#include <qmemarray.h>
+#include <qptrvector.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <math.h>
 #include <iostream>
@@ -119,12 +119,12 @@ class SDG {
  public:
   SDG() { TWO = (double)2.0; prevang = 0.0; ncalls = 0; leftright = false;
   arerings = true; }
-  void setAtoms(QVector<Atom> a1) { atomSet = a1; }
+  void setAtoms(QPtrVector<Atom> a1) { atomSet = a1; }
   void setRings(setOfRings s1) { sssr = s1; }
-  QVector<Atom> getAtoms() { return atomSet; }
+  QPtrVector<Atom> getAtoms() { return atomSet; }
   void setBL(double bl) { bondLength = bl; }
 
-  QVector<Atom> atomSet;
+  QPtrVector<Atom> atomSet;
   setOfRings sssr;
   double bondLength;
   double bondLineSep; 
@@ -152,11 +152,11 @@ class SDG {
   
   void draw(){
     int thisAtom = 0, neighbor = 0;
-    QArray<int> ilist(10);
+    QMemArray<int> ilist(10);
     int counter;
     SPoint tempPoint;
     bool vmit;
-    QArray<double> rot(10);
+    QMemArray<double> rot(10);
     int nrOfEdges = 0;
     for (int i = 0; i < atomSet.count(); i++)
       {
@@ -414,8 +414,8 @@ class SDG {
     int k = ring->size();
     Ring *secondRing = new Ring;
     int secondRingNumber = -1;
-    QList<Integer> complexAtoms, vect1, vect2, extComplAtoms;
-    QArray<int> ilist(10);
+    QPtrList<Integer> complexAtoms, vect1, vect2, extComplAtoms;
+    QMemArray<int> ilist(10);
     SPoint point, temp2Point, tempPoint;
     int atom, ringCounter, tempRing = -1, atom1 = -1, atom2 = -1, tempAtom = -1, il;
     int alreadyPositioned = -1, stillToPos, j, km, iz1, iz2, igr, ib = 0, ik = 0;
@@ -427,8 +427,8 @@ class SDG {
     bool isSpiro, isAlreadyPlaced, ums, vmit, doneSomething = false;
     FusedRingParams fRP;
     Atom n1, n2;
-    QArray<double> rot(10);
-    QArray<int> tempStatus(10);
+    QMemArray<double> rot(10);
+    QMemArray<int> tempStatus(10);
 		
     /* Search complex atoms (that are members of more than one ring)
        and preliminarily store their numbers in vector complexAtoms */
@@ -1037,7 +1037,7 @@ class SDG {
   /** Positions substituents around atom 'atomIndex' 
 	    Returns "-1" if no ring was drawn or the ring number of the ring draw */
   int positionAtomSubstituents(int atomIndex, SPoint point, SPoint helpPoint, 
-			       QArray<int> ilist, int modus, int ir, int igr){
+			       QMemArray<int> ilist, int modus, int ir, int igr){
     double ph =  0.0174532925;
     int    i, ib, ibb, iii, iph, k;
     double alph, b, phi, rad, xx, yy;
@@ -1054,7 +1054,7 @@ class SDG {
     if (sssr.size() > 0){
       ring = sssr.at(ir);
     }
-    QArray<double> rot(10);
+    QMemArray<double> rot(10);
     ib=0;
     k = atomSet[atomIndex]->degree;
     if (k <= 1) {
@@ -1135,13 +1135,13 @@ class SDG {
 	   rili[i] = 0 -> it's no ringatom
 	   rili[i] = x (x > 0) -> x is part of ring with size x
 	   */
-  QArray<double> angleOpt(int zatom, QArray<int> rili, bool vmit){
-    QArray<double> rot(10);
+  QMemArray<double> angleOpt(int zatom, QMemArray<int> rili, bool vmit){
+    QMemArray<double> rot(10);
     int    hatom = 0, i, kk, ll, neigh;
     bool   wahl;
     double sum, fewi, phi, alpha;
-    QArray<int> i1(10); QArray<int> i2(10);
-    QArray<double> i3(10); QArray<double> nclass(10);
+    QMemArray<int> i1(10); QMemArray<int> i2(10);
+    QMemArray<double> i3(10); QMemArray<double> nclass(10);
     for (int f = 0; f < 10; f++) rot[f] = (double)0;
     wahl = true;
     neigh = atomSet[zatom]->degree;
@@ -1364,7 +1364,7 @@ class SDG {
     int    nn, ia, ib, ii, il, kmm, iz1, iz2, isum1, isum2;
     double sux, suy, r, rad1, rad2;
     double alph, rad, phi, b, dist, xx, yy, r1, r2, dd;
-    QArray<int> ilist(10);
+    QMemArray<int> ilist(10);
     bool  vmit, ums, okay;
     Ring *ring = sssr.at(thisRingNumber);
     iz = 0;             
@@ -1412,8 +1412,8 @@ class SDG {
     double ph = 0.0174532925;
     int i = 0, id = 0, igr = 0, ihil = 0, ir = 0, iz = 0;
     int	k = 0, kk = 0, l = 0, ll = 0, modus = 0, result = -1;
-    QArray<int> remem(10);
-    QArray<int> ilist(10);
+    QMemArray<int> remem(10);
+    QMemArray<int> ilist(10);
     Ring *ring = new Ring;
     k = atomSet[thisAtom]->degree;
     if (k == 0) {
@@ -1530,15 +1530,15 @@ class SDG {
   /** This method resorts the node table of atom 'zatom' so that the most complex
       partner is located in the center of nodetable and the least complex partners
       are located at the beginning and the end of the nodetable.  */	
-  int resort(QArray<double> nclass, int neigh, int zatom, int hatom, 
-	     QArray<int> rili){
+  int resort(QMemArray<double> nclass, int neigh, int zatom, int hatom, 
+	     QMemArray<int> rili){
     int    i, j, k, kzaehl, kl;
     double min;
 
-    QArray<int> sbinex(10);
-    QArray<int> sbiord(10);
-    QArray<int> srili(10);
-    QArray<double> sclass(10);
+    QMemArray<int> sbinex(10);
+    QMemArray<int> sbiord(10);
+    QMemArray<int> srili(10);
+    QMemArray<double> sclass(10);
     k = 0;   
     for (i = 0; i < neigh; i++){
       if (i != hatom)	{ 
@@ -1646,8 +1646,8 @@ class SDG {
   /** Return a Vector that contains the intersection of Vectors vec1 
       and vec2 */
 	
-  QList<Integer> getIntersection(QArray<int> vec1, QArray<int> vec2){
-    QList<Integer> is;
+  QPtrList<Integer> getIntersection(QMemArray<int> vec1, QMemArray<int> vec2){
+    QPtrList<Integer> is;
     for (int f = 0; f < vec1.size(); f++){
       if (vec2.contains(vec1.at(f)) > 0) is.append(new Integer(vec1.at(f)));
     }	
