@@ -51,6 +51,8 @@ class Symbol : public Drawable {
   QPoint offset;
   // Rotation (if needed -- if not below or on point)
   double rotation;
+  // scale (if needed)
+  double scale;
 };
 
 #endif
