@@ -1,5 +1,6 @@
 // text.cpp - Text's implementation of functions
 
+// (obsolete note!)
 // NOTE ABOUT TEXTMASK: + marks superscript, - marks subscript
 // B marks bold, I marks italic, U marks underline
 
@@ -19,6 +20,8 @@ using std::endl;
 #include "text.h"
 #include "defs.h"
 
+// lastflag settings
+
 Text::Text(Render2D *r1, QObject *parent, const char *name)
   : Drawable(parent, name)
 {
@@ -38,6 +41,11 @@ Text::Text(Render2D *r1, QObject *parent, const char *name)
   tjustify = TEXT_AUTO;
   whichside = 1;
   DataType = TEXT_DATA_NORMAL;
+  shape = 0;
+  shapewidth = -1; shapeheight = -1;
+  oshapewidth = -1; oshapeheight = -1;
+  drawBorder = false; drawFill = false;
+  borderColor = QColor(0,0,0); fillColor = QColor(0,255,255);
 }
 
 QString Text::ToXML(QString xml_id) {
@@ -70,27 +78,60 @@ QString Text::ToXML(QString xml_id) {
   s.append(displayText);
   s.append("</richstring>\n");
 
-  /* QTextEdit saves these attributes as HTML in the <richstring> now
-  // write color
-  s.append("<color>");
-  n1.setNum(color.red());
+  // shape info
+  s.append("<shape>");
+  n1.setNum(shape);
   s.append(n1);
-  s.append(" ");
-  n1.setNum(color.green());
-  s.append(n1);
-  s.append(" ");
-  n1.setNum(color.blue());
-  s.append(n1);
-  s.append("</color>\n");
+  s.append("</shape>\n");
 
-  // write font
-  s.append("<font>");
-  s.append(font.family());
-  s.append(QString("#"));
-  n1.setNum(fsize);
+  // border info
+  s.append("<border>");
+  if (drawBorder == true)
+    s.append("true");
+  else
+    s.append("false");
+  s.append("</border>\n<bordercolor>");
+  n1.setNum(borderColor.red());
   s.append(n1);
-  s.append("</font>\n");
-  */
+  s.append(" ");
+  n1.setNum(borderColor.green());
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(borderColor.blue());
+  s.append(n1);
+  s.append("</bordercolor>\n");
+
+  // fill info
+  s.append("<fill>");
+  if (drawFill == true)
+    s.append("true");
+  else
+    s.append("false");
+  s.append("</fill>\n<fillcolor>");
+  n1.setNum(fillColor.red());
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(fillColor.green());
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(fillColor.blue());
+  s.append(n1);
+  s.append("</fillcolor>\n");
+
+  // shape dimensions
+  s.append("<shapegeometry>");
+  n1.setNum(shapewidth);
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(shapeheight);
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(oshapewidth);
+  s.append(n1);
+  s.append(" ");
+  n1.setNum(oshapeheight);
+  s.append(n1);
+  s.append("</shapegeometry>\n");
 
   // end text
   s.append("</text>\n");
@@ -142,6 +183,99 @@ void Text::FromXML(QString xml_tag) {
   i1 = xml_tag.find("<textmask>");
   i2 = xml_tag.find("</textmask>") + 11;
   SetTextmaskFromXML(xml_tag.mid(i1, i2 - i1));
+  i1 = xml_tag.find("<shape>");
+  if (i1 > 0) {
+    i2 = xml_tag.find("</shape>");
+    shape = xml_tag.mid(i1 + 7, i2 - i1 - 7).toInt();
+    std::cout << "shape:" << shape << std::endl;
+  }
+  i1 = xml_tag.find("<border>");
+  if (i1 > 0) {
+    i2 = xml_tag.find("</border>");
+    std::cout << "border:" << xml_tag.mid(i1 + 8, 4) << std::endl;
+    if (xml_tag.mid(i1 + 8, 4) == "true")
+      drawBorder = true;
+    else
+      drawBorder = false;
+  }
+  i1 = xml_tag.find("<fill>");
+  if (i1 > 0) {
+    i2 = xml_tag.find("</fill>");
+    std::cout << "fill:" << xml_tag.mid(i1 + 6, 4) << std::endl;
+    if (xml_tag.mid(i1 + 6, 4) == "true")
+      drawFill = true;
+    else
+      drawFill = false;
+  }
+  i1 = xml_tag.find("<bordercolor>");
+  if (i1 >= 0) {
+    i2 = xml_tag.find("</bordercolor>") + 14;
+    SetBorderColorFromXML(xml_tag.mid(i1, i2 - i1));
+  }
+  i1 = xml_tag.find("<fillcolor>");
+  if (i1 >= 0) {
+    i2 = xml_tag.find("</fillcolor>") + 12;
+    SetFillColorFromXML(xml_tag.mid(i1, i2 - i1));
+  }
+  i1 = xml_tag.find("<shapegeometry>");
+  if (i1 >= 0) {
+    i2 = xml_tag.find("</shapegeometry>") + 16;
+    SetShapeGeometryFromXML(xml_tag.mid(i1, i2 - i1));
+  }
+}
+
+void Text::SetBorderColorFromXML(QString xml_tag) {
+  cout << "SetBColorFromXML:" << xml_tag << endl;
+  int i1, i2;
+  int d1, d2, d3;
+
+  i1 = xml_tag.find("<bordercolor>");
+  i2 = xml_tag.find("</bordercolor>");
+  xml_tag.remove(i2, 999);
+  xml_tag.remove(i1, 13);
+
+  QTextStream ts(&xml_tag, IO_ReadOnly);
+
+  ts >> d1 >> d2 >> d3;
+
+  borderColor = QColor(d1, d2, d3);
+}
+
+void Text::SetFillColorFromXML(QString xml_tag) {
+  cout << "SetFColorFromXML:" << xml_tag << endl;
+  int i1, i2;
+  int d1, d2, d3;
+
+  i1 = xml_tag.find("<fillcolor>");
+  i2 = xml_tag.find("</fillcolor>");
+  xml_tag.remove(i2, 999);
+  xml_tag.remove(i1, 11);
+
+  QTextStream ts(&xml_tag, IO_ReadOnly);
+
+  ts >> d1 >> d2 >> d3;
+
+  fillColor = QColor(d1, d2, d3);
+}
+
+void Text::SetShapeGeometryFromXML(QString xml_tag) {
+  cout << "SetSGFromXML:" << xml_tag << endl;
+  int i1, i2;
+  int d1, d2, d3, d4;
+
+  i1 = xml_tag.find("<shapegeometry>");
+  i2 = xml_tag.find("</shapegeometry>");
+  xml_tag.remove(i2, 999);
+  xml_tag.remove(i1, 15);
+
+  QTextStream ts(&xml_tag, IO_ReadOnly);
+
+  ts >> d1 >> d2 >> d3 >> d4;
+
+  shapewidth = d1;
+  shapeheight = d2;
+  oshapewidth = d3;
+  oshapeheight = d4;
 }
 
 // convert XML <font> tag to QFont and set current
@@ -189,12 +323,14 @@ void Text::SetRichstringFromXML(QString xml_tag) {
 
 // get Text::textmask from <textmask> tag
 void Text::SetTextmaskFromXML(QString xml_tag) {
+  // not used!!!  either <richstring> or <elementmask> tag used to set display
+
   //cout << "SetTextmaskFromXML:" << xml_tag << endl;
 
   // obsolete tag!  silently update...
   // note that user may need to reformat text
-  displayText = start->element;
-  displayText.replace("\n", "</p>");
+  //displayText = start->element;
+  //displayText.replace("\n", "</p>");
 
   /*
   int i1, i2;
@@ -225,6 +361,11 @@ void Text::Render(void) {
   QFont currentFont = font;
   QColor currentColor = color;
 
+  if (r->getFontKludge()) {
+    currentFont.setPointSize( currentFont.pointSize() * 2 );
+    std::cout << "fontkludge (top)" << std::endl;    
+  }
+
   QStringList parseList, renderList, lineWidths;
 
   int lineheight = 0, linewidth = 0, textheight = 0, textwidth = 0;;
@@ -254,6 +395,7 @@ void Text::Render(void) {
 
   // mock render to determine width and height
   QRect b1;
+  int maxfont = 0, thisfont;
   for ( QStringList::Iterator it = parseList.begin(); it != parseList.end(); 
 	++it ) {
     currentElement = *it;
@@ -269,7 +411,13 @@ void Text::Render(void) {
     if (currentElement.left(3) == "<p ") continue;
     if (currentElement.left(6) == "<body ") continue;
     if (currentElement.left(6) == "<meta ") continue;
-    if (currentElement == "</span>") continue;
+    if (currentElement == "</span>") {
+      // this likely undoes a super/sub flag
+      if (superFlag == true) superFlag = false;
+      if (subFlag == true) subFlag = false;
+      renderList.append(currentElement);
+      continue;
+    }
     currentElement.replace("&lt;", "<");
     currentElement.replace("&gt;", ">");
     renderList.append(currentElement);
@@ -297,7 +445,14 @@ void Text::Render(void) {
 	lp2 = currentElement.find("font-size");
 	lp1 = currentElement.find(":", lp2);
 	lp2 = currentElement.find("pt", lp1);
-	currentFont.setPointSize( currentElement.mid(lp1 + 1, lp2 - lp1 - 1).toInt() );
+	thisfont = currentElement.mid(lp1 + 1, lp2 - lp1 - 1).toInt();
+	currentFont.setPointSize( thisfont );
+	if (thisfont > maxfont) maxfont = thisfont;
+	if ( r->getFontKludge() == true ) {
+	  currentFont.setPointSize( currentFont.pointSize() * 2 );
+	  std::cout << "fontkludge" << std::endl;
+	}
+	std::cout << "points: " << currentFont.pointSize() << std::endl;
       }
       currentFont.setBold(false);
       currentFont.setItalic(false);
@@ -347,9 +502,50 @@ void Text::Render(void) {
   QRect b(0, 0, textwidth, textheight);
   QPoint t = GetTopLeftPoint();
   b.moveBy( t.x(), t.y() );
+  // this guarantees that the text will not overlap other objects
   r->drawFillBox(b.topLeft(), b.bottomRight(), r->getBGColor(), false,
 		 QColor(0,0,0), 1);
 
+  // draw shape, if applicable
+  QPoint shapetl, shapebr, textcenter;
+  oshapewidth = b.width() + maxfont; oshapeheight = b.height() + maxfont;
+  textcenter.setX( b.left() + (b.width() / 2) );
+  textcenter.setY( b.top() + (b.height() / 2) );
+  int lsw, lsh;
+  if (shapewidth < 0) {
+    lsw = oshapewidth; lsh = oshapeheight;
+  } else {
+    lsw = shapewidth; lsh = shapeheight;
+  }
+  if (shape > 0) {
+    shapetl.setX( textcenter.x() - (lsw / 2) );
+    shapebr.setX( textcenter.x() + (lsw / 2) );
+    shapetl.setY( textcenter.y() - (lsh / 2) );
+    shapebr.setY( textcenter.y() + (lsh / 2) );
+    if (shape == TEXT_SHAPE_RECTANGLE) {
+      if (drawFill) {
+	r->drawFillBox(shapetl, shapebr, fillColor, drawBorder, borderColor,0);
+      } else {
+	r->drawBox(shapetl, shapebr, borderColor);
+      }
+    }
+    if (shape == TEXT_SHAPE_SQUARE) {
+      if (drawFill) {
+	r->drawFillBox(shapetl, shapebr, fillColor, drawBorder, borderColor,0);
+      } else {
+	r->drawBox(shapetl, shapebr, borderColor);
+      }
+    }
+    if (shape == TEXT_SHAPE_ELLIPSE) {
+      r->drawEllipse(shapetl, shapebr, drawBorder, borderColor, drawFill,
+		     fillColor);
+    }
+    if (shape == TEXT_SHAPE_CIRCLE) {
+      r->drawEllipse(shapetl, shapebr, drawBorder, borderColor, drawFill,
+		     fillColor);
+    }
+  }
+
   // right-align behavior is different for stand-alone text
   QTextStream dts(&displayTextMask, IO_ReadOnly);
   QString displayLine;
@@ -375,6 +571,11 @@ void Text::Render(void) {
   for ( QStringList::Iterator it = renderList.begin(); it != renderList.end(); 
 	++it ) {
     currentElement = *it;
+    if (currentElement == "</span>") {
+      boldFlag = false, italicFlag = false, underlineFlag = false,
+	superFlag = false, subFlag = false;      
+      continue;
+    }
     if ( currentElement == "</p>" ) {
       if (justify == JUSTIFY_CENTER) continue;
       r->resetTextOrigin();
@@ -409,6 +610,10 @@ void Text::Render(void) {
 	lp1 = currentElement.find(":", lp2);
 	lp2 = currentElement.find("pt", lp1);
 	currentFont.setPointSize( currentElement.mid(lp1 + 1, lp2 - lp1 - 1).toInt() );
+	if ( r->getFontKludge() == true ) {
+	  currentFont.setPointSize( currentFont.pointSize() * 2 );
+	  std::cout << "fontkludge" << std::endl;
+	}
       }
       currentFont.setBold(false);
       currentFont.setItalic(false);
