@@ -39,7 +39,8 @@ class Text : public Drawable {
   QPoint NearestCenter(QPoint, int, int &);
   void setText(QString nt1, QString nt2) { 
     if (start != 0) {
-      start->element = nt1; 
+      start->element = nt1; // element info (plain text)
+      start->elementmask = nt2;  // actual display text in underlying point!
       displayText = nt2;
     }
   }
@@ -58,7 +59,10 @@ class Text : public Drawable {
     else
       return "";
   }
-  void setTextMask(QString nm) { if (start != 0) start->elementmask = nm; }
+  void setTextMask(QString nm) { 
+    // this function is (probably) obsolete.  Use setText() instead.
+    //if (start != 0) start->elementmask = nm; 
+  }
   QString getTextMask() {
     if (start != 0)
       return start->elementmask; 
@@ -98,9 +102,40 @@ class Text : public Drawable {
   void SetTextstringFromXML(QString);
   void SetRichstringFromXML(QString);
   void SetTextmaskFromXML(QString);
+  void SetBorderColorFromXML(QString);
+  void SetFillColorFromXML(QString);
+  void SetShapeGeometryFromXML(QString);
   void CheckAlignment(int);
   void ForceAlignment(int);
   void UpdateDisplayText();
+  // set shape/border/fill
+  void setShape(int s1) {
+    shape = s1;
+  }
+  int getShape() { return shape; }
+  void setBorder(bool b1) { drawBorder = b1; }
+  bool getBorder() { return drawBorder; }
+  void setBorderColor(QColor c1) { borderColor = c1; }
+  QColor getBorderColor() { return borderColor; }
+  void setFill(bool b1) { drawFill = b1; }
+  bool getFill() { return drawFill; }
+  void setFillColor(QColor c1) { fillColor = c1; }
+  QColor getFillColor() { return fillColor; }
+  void setShapeWidth(int i1) {
+    shapewidth = i1;
+  }
+  void setShapeHeight(int i1) {
+    shapeheight = i1;
+  }
+  int getShapeWidth() {
+    if (shapewidth < 0) return oshapewidth;
+    return shapewidth;
+  }
+  int getShapeHeight() {
+    if (shapeheight < 0) return oshapeheight;
+    return shapeheight;
+  }
+
  private:
   // Renderer
   Render2D *r;
@@ -127,6 +162,12 @@ class Text : public Drawable {
   // Molecule this text gets data from
   Molecule *molecule;
   int DataType;
+  // shape/border/fill variables
+  int shape;  // 0 = no shape
+  bool drawBorder, drawFill;
+  QColor borderColor, fillColor;
+  int shapewidth, shapeheight;
+  int oshapewidth, oshapeheight;
 };
 
 #endif
