@@ -20,7 +20,6 @@ using std::endl;
 #include "defs.h"
 
 #include "ioiface.h"
-#include "mol.h"
 
 using namespace std;
 using namespace OpenBabel;
@@ -82,6 +81,7 @@ void Tool_2D3D::process() {
 }
 
 void Tool_2D3D::save3DFile() {
+  /* obsolete, and not even used, IIRC
   QStringList filters;
   io_type inFileType = UNDEFINED;
   int i;
@@ -137,4 +137,5 @@ void Tool_2D3D::save3DFile() {
     fileFormat.WriteMolecule(outFileStream, *mol, "3D", formatOptions); 
     delete new3dmol;
   }
+  */
 }
