@@ -5,7 +5,7 @@
 #include <qptrlist.h>
 #include <qpixmap.h>
 
-#include "mol.h"
+#include <openbabel/mol.h>
 #include "molecule.h"
 #include "peak.h"
 
