@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: xml_cml.h,v 1.1.1.1 2004/01/24 17:15:51 bherger Exp $
+** $Id: xml_cml.h,v 1.2 2005/05/18 01:06:37 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -12,7 +12,7 @@
 #define XML_CML_H
 
 #include <qxml.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 #include "drawable.h"
 #include "dpoint.h"
@@ -37,12 +37,12 @@ public:
     bool endElement( const QString&, const QString&, const QString& );
     bool characters( const QString& );
     bool ignorableWhitespace( const QString& );
-    QList<DPoint> getPoints();
-    QList<Bond> getBonds();
+    QPtrList<DPoint> getPoints();
+    QPtrList<Bond> getBonds();
 
 private:
-    QList<DPoint> localPoints;
-    QList<Bond> localBonds;
+    QPtrList<DPoint> localPoints;
+    QPtrList<Bond> localBonds;
     DPoint *tmp_pt, *ep1, *ep2;
     Bond *tmp_bond;
     Render2D *r;
